/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz;

import java.awt.EventQueue;
import java.awt.Font;
import java.util.Enumeration;

import javax.imageio.ImageIO;
import javax.swing.UIManager;

import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.swing.MainWindow;

public class GPViz
{
  public static final String PROGRAM_NAME="GPViz";
  
  public static final String VERSION="1.2.6";
  
  public static final String VERSION_DATE="27.03.2013";
  
  public static final String URL="http://icbi.i-med.ac.at/gpviz/";
  
  public static final String CITATION="Publication in works. Citation follows.";
  
  public static final long MEMORY_WARNING_UPPER_THRESHOLD = (long)(Runtime.getRuntime().maxMemory()*0.15d);
  
  public static final long MEMORY_WARNING_LOWER_THRESHOLD = (long)(Runtime.getRuntime().maxMemory()*0.12d);
  
  public static final long MAX_DRAW_WIDTH_IN_GUI = 6000;
  public static final long MAX_DRAW_HEIGHT_IN_GUI = 6000;
  
  private final GPVDataContainer data = new GPVDataContainer();
  
  private GPVOptions options;
  
  public static boolean AIMONK = false;
  
  private void init(){
    setOptions(GPVOptions.load());
  }
  
  public GPVOptions getOptions()
  {
    return options;
  }

  public void setOptions(GPVOptions options)
  {
    this.options = options;
  }

  public GPVDataContainer getDataContainer(){
    return data;
  }
  
  
  private static GPViz instance = null;
  
  public static GPViz getInstance(){
    return instance;
  }
  
  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    ImageIO.scanForPlugins(); 
    Enumeration<Object> keys =  UIManager.getDefaults().keys();
    while(keys.hasMoreElements()){
      Object key = keys.nextElement();
      Object value = UIManager.get(key);
      if(value instanceof Font){
        UIManager.put(key, ((Font)value).deriveFont(Font.PLAIN));
      }
    }
    
    instance = new GPViz();
    instance.init();
    
    EventQueue.invokeLater(new Runnable()
    {
      public void run()
      {
        try
        {
          MainWindow window = new MainWindow();
          window.setLocationRelativeTo(null);
          window.setVisible(true);
        }
        catch (Exception e)
        {
          e.printStackTrace();
        }
      }
    });
  }
}
