/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data;

import java.util.Comparator;

import at.icbi.gpviz.data.util.GPVUtils;

public class GPVChromosome implements Comparable<GPVChromosome>
{
  private String name;
  private String trimmedName;
  private int chrom_ordinal;

  public GPVChromosome(String name){
    setName(name);
  }
  
  public String getName()
  {
    return name;
  }

  public void setName(String name)
  {
    this.name = name.intern();
    this.trimmedName = GPVUtils.getChromsomeName(this.name).toLowerCase().intern();
    
    this.chrom_ordinal = getChromOrdinal(trimmedName);
  }
  
  public String getTrimmedName(){
    return this.trimmedName;
  }

  @Override
  public int compareTo(GPVChromosome o)
  {
    return new FastChromosomeComparator().compare(this, o);
  }
  
  public boolean equals(GPVChromosome c){
    //i can compare like that because i internalized them
    return this.trimmedName == c.getTrimmedName();
  }

  
  private int getChromOrdinal(String chromosome) throws NumberFormatException{
    String chrom_n = chromosome.toLowerCase();
    chrom_n = chrom_n.replaceAll("_.*", "").trim(); //remove possible suffix
    
    if(chrom_n.toLowerCase().equals("m")){
      return 0;
    }
    if(chrom_n.toLowerCase().equals("x")){
      return 1000;
    }
    if(chrom_n.toLowerCase().equals("y")){
      return 1001;
    }
    if(chrom_n.toLowerCase().equals("un")){
      return 1002;
    }
    
    try{
      Integer chrom_num = Integer.parseInt(chromosome);
      return chrom_num;
    }catch(NumberFormatException nfe){
      return -1;
    }
  }
  
  int getOrdinal(){
    return chrom_ordinal;
  }
}

class FastChromosomeComparator implements Comparator<GPVChromosome>{
  @Override
  public int compare(GPVChromosome o1, GPVChromosome o2)
  {
    int ret = o1.getOrdinal()-o2.getOrdinal();
    if(ret!=0)return ret;
    return o1.getTrimmedName().compareTo(o2.getTrimmedName());
  }
}
