/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data;

import java.util.HashMap;

public class GPVDomain implements Cloneable
{
  private GPVDomainSet parentSet;
  
  private int proteinStartPos;
  private int proteinEndPos;
  
  private String description;
  private String domainId;
  
  private String proteinId;
  
  private HashMap<String,String> additionalData;
  
  
  public GPVDomainSet getParentSet()
  {
    return parentSet;
  }
  public void setParentSet(GPVDomainSet parentSet)
  {
    this.parentSet = parentSet;
  }
  public int getProteinStartPos()
  {
    return proteinStartPos;
  }
  public void setProteinStartPos(int proteinStartPos)
  {
    this.proteinStartPos = proteinStartPos;
  }
  public int getProteinEndPos()
  {
    return proteinEndPos;
  }
  public void setProteinEndPos(int proteinEndPos)
  {
    this.proteinEndPos = proteinEndPos;
  }
  public String getDescription()
  {
    return description;
  }
  public void setDescription(String description)
  {
    this.description = description;
  }
  public String getDomainId()
  {
    return domainId;
  }
  public void setDomainId(String domainId)
  {
    this.domainId = domainId;
  }
  public String getProteinId()
  {
    return proteinId;
  }
  public void setProteinId(String proteinId)
  {
    this.proteinId = proteinId;
  }
  public HashMap<String,String> getAdditionalData()
  {
    return additionalData;
  }
//  public void setAdditionalData(HashMap<String,String> additionalData)
//  {
//    this.additionalData = additionalData;
//  }
  public void addAdditionalData(String key, String value){
    //this saves us memory. We should not initialize the map unless we really have to
    if(value!=null && !value.equals("")){
      if(additionalData==null)additionalData = new HashMap<String,String>(1);
      this.additionalData.put(key,value);
    }
  }
  public boolean overlaps(GPVDomain domain){
    if(domain.getParentSet() == this.getParentSet()){
      if((domain.getProteinStartPos() >= this.getProteinStartPos() && domain.getProteinStartPos() <= this.getProteinEndPos()) ||
          (domain.getProteinEndPos() >= this.getProteinStartPos() && domain.getProteinEndPos() <= this.getProteinEndPos()) ||
          (domain.getProteinStartPos() < this.getProteinStartPos() && domain.getProteinEndPos() > this.getProteinEndPos())  ){
        if(domain.getDescription().equals(this.getDescription())){
          if(domain.getProteinId().equals(this.getProteinId())){
            return true;            
          }
        }
      }
    }
    return false;
  }
  
  @Override
  public GPVDomain clone(){
    GPVDomain ret = new GPVDomain();
    ret.setDescription(this.getDescription());
    ret.setDomainId(this.getDomainId());
    ret.setParentSet(this.getParentSet());
    ret.setProteinEndPos(this.getProteinEndPos());
    ret.setProteinId(this.getProteinId());
    ret.setProteinStartPos(this.getProteinStartPos());
    return ret;
  }
}
