/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Vector;

import at.icbi.gpviz.GPViz;

public class GPVDomainSet
{

  private String setName;
  private List<GPVDomain> domains = new ArrayList<GPVDomain>();

  //cache for faster searching
  private HashMap<String,List<GPVDomain>> domainsByProteinID;

  private boolean enabled = true;


  public String getSetName()
  {
    return setName;
  }
  public void setSetName(String setName)
  {
    this.setName = setName;
  }
  public List<GPVDomain> getDomains()
  {
    return domains;
  }
  
  public List<GPVDomain> getDomainsForProteinID(String id){
    if(checkCache()){
      return domainsByProteinID.get(id);
    }else{
      List<GPVDomain> ret = new ArrayList<GPVDomain>();
      for(GPVDomain domain:domains){
        if(domain.getDomainId().equals(id)) ret.add(domain);
      }
      return ret;
    }
  }
  
  private boolean checkCache(){
    boolean required = GPViz.getInstance().getOptions().isUseProteinDomainCache();
    if(required){
      if(domainsByProteinID==null)updateCache();
    }else{
      if(domainsByProteinID!=null)updateCache();      
    }
    return required;
  }

  public void setDomains(List<GPVDomain> domains)
  {
    this.domains = domains;
    updateCache();
  }
  public void addDomain(GPVDomain domain, boolean updatecache){
    this.domains.add(domain);
    if(updatecache)addToCache(domain);
  }
  public void addDomain(GPVDomain domain){
    addDomain(domain,true);
  }
  public boolean isEnabled()
  {
    return enabled;
  }
  public void setEnabled(boolean enabled)
  {
    this.enabled = enabled;
  }

  public void updateCache(){
    if(GPViz.getInstance().getOptions().isUseProteinDomainCache()){
      domainsByProteinID = new HashMap<String,List<GPVDomain>>();
      for(GPVDomain domain:domains){
        addToCache(domain);
      }
    }
  }
  private void addToCache(GPVDomain domain){
    if(GPViz.getInstance().getOptions().isUseProteinDomainCache()){
      if(domainsByProteinID==null)domainsByProteinID = new HashMap<String,List<GPVDomain>>();
      List<GPVDomain> list = domainsByProteinID.get(domain.getProteinId());
      if(list==null){
        list = new Vector<GPVDomain>();
        domainsByProteinID.put(domain.getProteinId(),list);
      }
      list.add(domain);
    }
  }
}
