/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data;

import at.icbi.gpviz.data.GPVDataContainer.DOMAIN_SOURCE;
import at.icbi.gpviz.data.util.GPVUtils;

public class GPVProtein
{
  private String proteinid;
  private String proteinUniprotId;
  
  private GPVTranscript parent;
  
  public GPVProtein(){
  }
  
  public GPVProtein(String refseqid){
    this.proteinid = refseqid;
  }

  public GPVTranscript getParent()
  {
    return parent;
  }

  public void setParent(GPVTranscript parent)
  {
    this.parent = parent;
  }

  public String getProteinUniprotId()
  {
    return proteinUniprotId;
  }
  public void setProteinUniprotId(String proteinId)
  {
    this.proteinUniprotId = proteinId;
  }

  /**
   * May be null, if no annotation file has been loaded 
   */
  public String getProteinID()
  {
    return proteinid;
  }
  public void setProteinID(String id)
  {
    proteinid = id;
  }
  
  public String getIDFrom(DOMAIN_SOURCE source){
    String protid;
    switch(source){
      case UNIPROT:
        protid = getProteinUniprotId();
        break;
      default:
        protid = getProteinID();
    }
    return protid;
  }
  
  public int getProteinLength(){
    int totalCodingExonLength =0; 
    for(GPVExon exon:parent.getAllExonRegionsSeparately(false)){
      totalCodingExonLength+=Math.abs(exon.getEndPos()-exon.getStartPos())+1;
    }
    return GPVUtils.nt2Prot(totalCodingExonLength)+1;
  }
  
}
