/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.filter;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVDomain;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVTranscript;
import at.icbi.gpviz.data.regions.GPVHighlightedRegion;
import at.icbi.gpviz.data.util.GPVUtils;

public class DomainsAffectedGeneFilter extends GeneFilter
{
  private GPVDataContainer data;
  
  public static final String FILTER_NAME = "Affected domains";
  
  public DomainsAffectedGeneFilter(){
    data = GPViz.getInstance().getDataContainer();
  }
  
  @Override
  public boolean accept(GPVGene gene)
  {
    boolean ret = isGeneHasProteinDomainsEffected(gene);
    return ret;
  }
  
  public boolean isGeneHasProteinDomainsEffected(GPVGene selectedGene){
    Collection<GPVHighlightedRegion> regions_in_gene = data.getHighlightedRegionsForGene(selectedGene,false);
    if(regions_in_gene!=null && regions_in_gene.size()>0){
      HashMap<String,ArrayList<GPVDomain>> all_domains = data.getProteinDomainsForGene(selectedGene);
      if(all_domains!=null && all_domains.size()>0){
        for(GPVTranscript transcript:selectedGene.getTranscripts().values()){
          if(transcript.isCoding()){
            ArrayList<GPVDomain> prot_domains = all_domains.get(transcript.getResultingProtein().getProteinID());
            if(prot_domains!=null && prot_domains.size()>0){
              Collection<GPVHighlightedRegion> regions_in_transcript = GPVUtils.splitRegionsInCodingRegions(transcript, regions_in_gene);
              regions_in_transcript = GPVUtils.splitRegionsInProteinDomainRegions(transcript, prot_domains, regions_in_transcript);
              
              if(regions_in_transcript.size()>0)return true;
            }
          }
        }
      }
    }
    
    return false;
  }

  @Override
  public String getFilterDescription()
  {
    return FILTER_NAME;
  }

}
