/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.filter;

import java.util.Collection;
import java.util.HashMap;


public class GeneFilterCache 
{

  private HashMap<String, boolean[]> filter_result;
  private HashMap<String, GeneFilter> filters;
  
  private int num_genes = 0;

  public GeneFilterCache(){
    clearFilters();
  }
  
  
  public void clearFilters(){
    this.filter_result = new HashMap<String,boolean[]>();
    this.filters = new HashMap<String,GeneFilter>();
    num_genes = 0;
  }
  
  public void addFilter(GeneFilter filter, boolean[] results){
    filter_result.put(filter.getFilterDescription(),results);
    filters.put(filter.getFilterDescription(), filter);
    if(num_genes>0){
      if(results.length!=num_genes){
        throw new IllegalArgumentException("Incompatible number of genes.");
      }
    }else{
      num_genes = results.length;
    }
  }

  public String getFilterDescription()
  {
    return "Filter cache";
  }
  
  public int getNumberOfFilters(){
    return filter_result.size();
  }

  public void removeFilter(GeneFilter filter){
    filter_result.remove(filter.getFilterDescription());
    filters.remove(filter.getFilterDescription());
  }
  
  public void removeFilter(String filtername){
    filter_result.remove(filtername);
    filters.remove(filtername);
  }
  
  public GeneFilter getFilter(String filtername){
    return filters.get(filtername);
  }
  
  public Collection<GeneFilter> getFilters(){
    return filters.values();
  }
  
  public boolean[] getResultsFromCache(){
    boolean[] ret = new boolean[num_genes];
    for(int i = 0; i < ret.length; i++)ret[i]=true;
    
    for(boolean[] results:filter_result.values()){
      for(int i = 0; i < results.length; i++){
        ret[i] = ret[i] && results[i];
      }
    }
    return ret;
  }

  
}
