/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.filter;

import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVTranscript;

public class MinNumberOfCodingTranscriptsGeneFilter extends GeneFilter
{
  private static final String FILTER_NAME = "Minimum Number of Coding Transcripts";
  
  private int number;
  
  public MinNumberOfCodingTranscriptsGeneFilter(int number){
    this.number = number;
  }
  
  @Override
  public boolean accept(GPVGene gene)
  {
    int nr = 0;
    for(GPVTranscript tr: gene.getTranscripts().values()){
      if(tr.isCoding()) nr++;
      if(nr>=number)return true;
    }
    return false;
  }

  @Override
  public String getFilterDescription()
  {
    return FILTER_NAME;
  }
  
  public static String createFilterName(int number){
    return FILTER_NAME+" >="+number;
  }

}
