/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.filter;

import java.util.TreeSet;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.regions.GPVHighlightedRegion;

public class VariantsIntersectingRegionsGeneFilter extends GeneFilter
{
  private GPVDataContainer data;
  public static final String FILTER_NAME = "Variants intersecting regions";
  
  public VariantsIntersectingRegionsGeneFilter(){
    data = GPViz.getInstance().getDataContainer();
  }
  
  @Override
  public boolean accept(GPVGene gene)
  {
    TreeSet<GPVHighlightedRegion> regions = data.getHighlightedRegionsForGene(gene,false,true,false);
    if(regions.size()>0){
      TreeSet<GPVHighlightedRegion> variants = data.getHighlightedRegionsForGene(gene,true,false,false);
      if(variants.size()>0){
        for(GPVHighlightedRegion region:regions){
          for(GPVHighlightedRegion variant:variants){
            if(region.contains(variant)){
              return true;
            }
          }
        }
      }
    }
    
    return false;
  }

  @Override
  public String getFilterDescription()
  {
    return FILTER_NAME;
  }

}
