/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.anno;

import java.io.File;
import java.io.FileNotFoundException;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.data.GPVProtein;
import at.icbi.gpviz.data.GPVTranscript;
import at.icbi.gpviz.data.loader.parser.EnsemblUniprotEntry;
import at.icbi.gpviz.data.loader.parser.EnsemblUniprotParser;
import at.tugraz.genome.biojava.exception.RawEntryReaderException;
import at.tugraz.genome.biojava.io.EntryCreationException;
import at.tugraz.genome.biojava.io.EntryReader;
import at.tugraz.genome.biojava.io.RawEntry;

public class EnsemblUniprotLoader
{

  public void loadEnsemblAndUniprotData(JFrame parent){
    GPVOptions options = GPViz.getInstance().getOptions();
    if(options!=null && options.getEnsemblToUniprotFile()!=null){
      File toload = new File(options.getEnsemblToUniprotFile());

      GPVDataContainer data = GPViz.getInstance().getDataContainer();
      EnsemblUniprotParser parser = new EnsemblUniprotParser();

      
      try{
        EntryReader<EnsemblUniprotEntry> reader = new EntryReader<EnsemblUniprotEntry>(toload,parser);

        RawEntry raw_entry;
        while((raw_entry = reader.next())!=null){
          EnsemblUniprotEntry dsventry = parser.parseEntry(raw_entry);
          GPVGene gene = data.getGenes().get(dsventry.getEnsemblGeneID());
          if(gene!=null){
            gene.setGeneFullName(dsventry.getGeneFullName());
            gene.setGeneSymbol(dsventry.getGeneSymbol());
            GPVTranscript transcript = gene.getTranscripts().get(dsventry.getEnsemblTranscriptID());
            if(transcript !=null){
              GPVProtein prot = transcript.getResultingProtein();
              if(prot==null){
                prot = new GPVProtein(dsventry.getEnsemblProteinID());
                transcript.setResultingProtein(prot);
              }else{
                prot.setProteinID(dsventry.getEnsemblProteinID());
              }
              prot.setProteinUniprotId(dsventry.getProteinUniprotId());
            }
          }
        }

      }
      catch (RawEntryReaderException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Ensembl Annotation file. " +e.getMessage());
        e.printStackTrace();
      }
      catch (FileNotFoundException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Ensembl Annotation file. " +e.getMessage());
        e.printStackTrace();
      }
      catch (EntryCreationException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Ensembl Annotation file. " +e.getMessage());
        e.printStackTrace();
      }
    }
  }
}
