/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.anno;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.HashMap;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.data.GPVProtein;
import at.icbi.gpviz.data.GPVTranscript;
import at.icbi.gpviz.data.loader.parser.RefseqUniprotEntry;
import at.icbi.gpviz.data.loader.parser.RefseqUniprotParser;
import at.tugraz.genome.biojava.exception.RawEntryReaderException;
import at.tugraz.genome.biojava.io.EntryCreationException;
import at.tugraz.genome.biojava.io.EntryReader;
import at.tugraz.genome.biojava.io.RawEntry;

public class RefseqUniprotLoader
{

  public void loadRefseqAndUniprotData(JFrame parent){
    GPVOptions options = GPViz.getInstance().getOptions();
    if(options!=null && options.getNMtoNPFile()!=null){
      File toload = new File(options.getNMtoNPFile());

      GPVDataContainer data = GPViz.getInstance().getDataContainer();
      RefseqUniprotParser parser = new RefseqUniprotParser();

      try{
        EntryReader<RefseqUniprotEntry> reader = new EntryReader<RefseqUniprotEntry>(toload,parser);

        HashMap<String, GPVTranscript> transcripts = new HashMap<String,GPVTranscript>();
        for(GPVGene gene:data.getGenes().values()){
          for(GPVTranscript tr:gene.getTranscripts().values()){
            transcripts.put(tr.getTranscriptId(), tr);
          }
        }
        RawEntry raw_entry;
        while((raw_entry = reader.next())!=null){
          RefseqUniprotEntry dsventry = parser.parseEntry(raw_entry);
          GPVTranscript transcript = transcripts.get(dsventry.getTranscriptRefseqID());
          if(transcript!=null){
            GPVGene gene = transcript.getParent();
            gene.setUniGeneID(dsventry.getGeneID());
            gene.setGeneFullName(dsventry.getGeneFullName());
            if(transcript !=null){
              GPVProtein prot = transcript.getResultingProtein();
              if(prot==null){
                prot = new GPVProtein(dsventry.getProteinRefseqID());
                transcript.setResultingProtein(prot);
              }else{
                prot.setProteinID(dsventry.getProteinRefseqID());
              }
              prot.setProteinUniprotId(dsventry.getProteinUniprotId());
            }
          }
        }

      }
      catch (RawEntryReaderException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Refseq annotation file. " +e.getMessage());
        e.printStackTrace();
      }
      catch (FileNotFoundException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Refseq annotation file. " +e.getMessage());
        e.printStackTrace();
      }
      catch (EntryCreationException e)
      {
        JOptionPane.showMessageDialog(parent, "Error loading Refseq annotation file. " +e.getMessage());
        e.printStackTrace();
      }
    }
  }
}
