/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.domains;

import java.util.Collection;
import java.util.HashSet;

import at.icbi.gpviz.data.GPVDataContainer.DOMAIN_SOURCE;
import at.icbi.gpviz.data.GPVDomain;
import at.icbi.gpviz.data.loader.domains.parser.GPVizDomainsEntry;
import at.icbi.gpviz.data.loader.domains.parser.GPVizDomainsParser;
import at.tugraz.genome.biojava.io.dsv.AbstractDSVParser;

public class GPVizProteinDomainLoader extends AbstractProteinDomainLoader<GPVizDomainsEntry>
{
  public static final String ADDITIONAL_DATA_LONG_NAME_KEY = "Long name";
  public static final String ADDITIONAL_DATA_COMMENT_KEY = "Comment";

  @Override
  protected AbstractDSVParser<GPVizDomainsEntry> getParser()
  {
    return new GPVizDomainsParser();
  }

  @Override
  protected Collection<String> getAdditionalDataKeys()
  {
    HashSet<String> ret = new HashSet<String>();
    ret.add(ADDITIONAL_DATA_LONG_NAME_KEY);
    ret.add(ADDITIONAL_DATA_COMMENT_KEY);
    return ret;
  }

  @Override
  protected void addAdditionalData(GPVDomain domain, GPVizDomainsEntry entry)
  {
    domain.addAdditionalData(ADDITIONAL_DATA_LONG_NAME_KEY,entry.getLongName());
    domain.addAdditionalData(ADDITIONAL_DATA_LONG_NAME_KEY,entry.getLongName());
  }

  @Override
  protected boolean validateEntry(GPVizDomainsEntry entry)
  {
    try{
    return entry.getProteinID()!=null && entry.getTo()>=0 && entry.getFrom()>=0;
    }catch(NumberFormatException nfe){
      return false;
    }
  }

  @Override
  protected DOMAIN_SOURCE getDomainIDSource()
  {
    return DOMAIN_SOURCE.GENERIC;
  }
}
