/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.domains;

import java.util.Collection;
import java.util.HashSet;

import at.icbi.gpviz.data.GPVDataContainer.DOMAIN_SOURCE;
import at.icbi.gpviz.data.GPVDomain;
import at.icbi.gpviz.data.loader.domains.parser.PFAMDomainsEntry;
import at.icbi.gpviz.data.loader.domains.parser.PFAMDomainsParser;
import at.tugraz.genome.biojava.io.dsv.AbstractDSVParser;

public class PFAMProteinDomainLoader extends AbstractProteinDomainLoader<PFAMDomainsEntry>
{

  @Override
  protected AbstractDSVParser<PFAMDomainsEntry> getParser()
  {
    return new PFAMDomainsParser();
  }

  @Override
  protected Collection<String> getAdditionalDataKeys()
  {
    HashSet<String> ret = new HashSet<String>();
    return ret;
  }

  @Override
  protected void addAdditionalData(GPVDomain domain, PFAMDomainsEntry entry)
  {
  }
  
  @Override
  protected boolean validateEntry(PFAMDomainsEntry entry)
  {
    try{
    return entry.getID().toUpperCase().startsWith("PF") && entry.getTo()>=0 && entry.getFrom()>=0;
    }catch(NumberFormatException nfe){
      return false;
    }
  }

  @Override
  protected DOMAIN_SOURCE getDomainIDSource()
  {
    return DOMAIN_SOURCE.UNIPROT;
  }

}
