/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.domains.parser;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class CDDBEntry extends ProteinDomainEntry
{
  public static int COL_PROTID = 0;
  public static int COL_HITTYPE = 1;
  public static int COL_PSSM = 2;
  public static int COL_FROM = 3;
  public static int COL_TO = 4;
  public static int COL_EVALUE = 5;
  public static int COL_BITSCORE = 6;
  public static int COL_ACCESSION = 7;
  public static int COL_SHORTNAME = 8;
  
  
  public CDDBEntry(String[] columns)
  {
    super(columns);
    
    Pattern proteinIdRegex = Pattern.compile(".*(NP_\\d*)");
    Matcher mitch = proteinIdRegex.matcher(this.getProteinID());
    if(mitch.find()){
      String real_protein_id = mitch.group(1);
      super.setColumn(COL_PROTID, real_protein_id);
    }else{
      System.err.println("Invalid protein ID field: "+this.getProteinID());
    }
  }
  
  public String getProteinID(){
    return this.getColumn(COL_PROTID);
  }
  
  public String getHitType(){
    return this.getColumn(COL_HITTYPE);
  }
  public String getPSSMId(){
    return this.getColumn(COL_PSSM);
  }
  
  public int getFrom(){
    return Integer.parseInt(this.getColumn(COL_FROM));
  }
  
  public int getTo(){
    return Integer.parseInt(this.getColumn(COL_TO));
  }
  
  public double getEValue(){
    return Double.parseDouble(this.getColumn(COL_EVALUE));
  }
  
  public double getBitScore(){
    return Double.parseDouble(this.getColumn(COL_BITSCORE));
  }
  
  public String getAccession(){
    return this.getColumn(COL_ACCESSION);
  }
  
  public String getShortName(){
    return this.getColumn(COL_SHORTNAME);
  }
  
  public String getID(){
    return getAccession();
  }

}
