/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.variants;



import at.icbi.gpviz.data.GPVChromosome;
import at.icbi.gpviz.data.regions.GPVVariant;
import at.icbi.gpviz.data.regions.GPVVariantConstants;
import at.icbi.gpviz.data.regions.GPVVariantType;
import at.tugraz.genome.biojava.io.dsv.maf.MAFConstants.VariantClassification;
import at.tugraz.genome.biojava.io.dsv.maf.MAFConstants.VariantType;
import at.tugraz.genome.biojava.io.dsv.maf.MAFEntry;
import at.tugraz.genome.biojava.io.dsv.maf.MAFParser;
import at.tugraz.genome.biojava.seq.DNAStrand;

public class MAFFileVariantLoader extends AbstractVariantLoader<MAFEntry>
{
  
  @Override
  protected GPVVariant getVariant(MAFEntry maf)
  {
    DNAStrand strand =maf.getStrand();
    String chrom = maf.getChrom();
    int start = maf.getStartPosition();

    GPVChromosome chromosome = new GPVChromosome("chr"+chrom);
    GPVVariant variant = new GPVVariant(chromosome, start, strand);
    variant.setDbSNPID(maf.getDbsnpRs());
    variant.setVariantType(mapVariantType(maf.getVariantClassification(), maf.getVariantType()));
    return variant;
  }

  @Override
  protected MAFParser getParser() 
  {
    MAFParser parser = new MAFParser(false); 
    return parser;
  }

  @Override
  protected String getFormatName()
  {
    return "MAF";
  }
  
  private GPVVariantType mapVariantType(VariantClassification classification, VariantType type){
    if(classification == VariantClassification.Frame_Shift_Ins && type == VariantType.INS){
      return GPVVariantConstants.Frame_Shift_Insertion;
    }else if(classification == VariantClassification.Frame_Shift_Del && type == VariantType.DEL){
      return GPVVariantConstants.Frame_Shift_Deletion;
    }else if(classification == VariantClassification.In_Frame_Del && type == VariantType.DEL){
      return GPVVariantConstants.In_Frame_Deletion;
    }else if(classification == VariantClassification.In_Frame_Ins && type == VariantType.INS){
      return GPVVariantConstants.In_Frame_Insertion;
    }else if(classification == VariantClassification.Silent && type == VariantType.SNP){
      return GPVVariantConstants.Silent_SNP;
    }else if(classification == VariantClassification.Nonsense_Mutation && type == VariantType.SNP){
      return GPVVariantConstants.Nonsense_SNP;
    }else if(classification == VariantClassification.Missense_Mutation && type == VariantType.SNP){
      return GPVVariantConstants.Missense_SNP;
    } 
    
    return GPVVariantConstants.Other;
  }

  @Override
  protected boolean validateEntry(MAFEntry entry)
  {
    try{
      if(entry.getStartPosition()<=0)return false;
      if(entry.getEndPosition()<=0)return false;
      entry.getVariantClassification();
    }catch(Exception e){
      return false;
    }
    return true;
  }

  @Override
  protected boolean needsDynamicVariantScheme()
  {
    return false;
  }


}