/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.variants;



import at.icbi.gpviz.data.GPVChromosome;
import at.icbi.gpviz.data.regions.GPVVariant;
import at.tugraz.genome.biojava.io.dsv.mut.MUTEntry;
import at.tugraz.genome.biojava.io.dsv.mut.MUTParser;

public class MUTFileVariantLoader extends AbstractVariantLoader<MUTEntry>
{
  
  @Override
  protected GPVVariant getVariant(MUTEntry mut)
  {
    String chrom = mut.getChromosome();
    int start = mut.getStart();

    GPVChromosome chromosome = new GPVChromosome(chrom);
    GPVVariant variant = new GPVVariant(chromosome, start);
    variant.setOriginalVariantType(mut.getMutationType());
    return variant;
  }

  @Override
  protected MUTParser getParser() 
  {
    MUTParser parser = new MUTParser(); 
    return parser;
  }

  @Override
  protected String getFormatName()
  {
    return "MUT";
  }

  @Override
  protected boolean validateEntry(MUTEntry entry)
  {
    try{
      if(entry.getStart()<=0)return false;
      if(entry.getEnd()<=0)return false;
      
    }catch(Exception e){
      return false;
    }
    return true;
  }

  @Override
  protected boolean needsDynamicVariantScheme()
  {
    return true;
  }


}