/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.variants;



import at.icbi.gpviz.data.GPVChromosome;
import at.icbi.gpviz.data.regions.GPVVariant;
import at.tugraz.genome.biojava.io.vcf.VCFEntry;
import at.tugraz.genome.biojava.io.vcf.VCFParser;

public class VCFFileVariantLoader extends AbstractVariantLoader<VCFEntry>
{
  
  @Override
  protected GPVVariant getVariant(VCFEntry vcf)
  {
    String chrom = vcf.getChromosome();
    int start = vcf.getPosition();

    GPVChromosome chromosome = new GPVChromosome(chrom);
    GPVVariant variant = new GPVVariant(chromosome, start);
    String svtype = vcf.getInfoValue("SVTYPE");
    if(svtype==null){
      if(vcf.getRef().length()==1 && vcf.getAlt()[0].length()==1){
        svtype="SNP";  
      }else if(vcf.getRef().length()==1){
        svtype="Insertion";
      }else if(vcf.getAlt()[0].length()==1){
        svtype="Deletion";
      }else{
        svtype="Other";
      }
    }
    
    variant.setOriginalVariantType(svtype);
    return variant;
  }

  @Override
  protected VCFParser getParser() 
  {
    VCFParser parser = new VCFParser();
    
    
    return parser;
  }

  @Override
  protected String getFormatName()
  {
    return "VCF";
  }

  @Override
  protected boolean validateEntry(VCFEntry entry)
  {
    try{
      if(entry.getPosition()<=0)return false;
      if(entry.getRef().length()<=0)return false;
      
    }catch(Exception e){
      return false;
    }
    return true;
  }

  @Override
  protected boolean needsDynamicVariantScheme()
  {
    return true;
  }


}