/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.loader.variants;

import java.io.File;

import at.tugraz.genome.biojava.io.ParsedEntry;
import at.tugraz.genome.util.FileUtils;

public class VariantLoaderHelper
{
  
  public static AbstractVariantLoader<?> chooseFormat(File inputfile){
    AbstractVariantLoader<?> ret = chooseFormatBasedOnExtension(inputfile);
    if(ret==null) ret = chooseFormatBasedOnContent(inputfile);
    
    return ret;
  }
  
  private static AbstractVariantLoader<?> chooseFormatBasedOnExtension(File inputfile){
    final String extension = FileUtils.getExtension(inputfile.getName()).toLowerCase();
    
    switch(extension){
      case "maf": return new MAFFileVariantLoader();
      case "mut": return new MUTFileVariantLoader();
      case "vcf": return new VCFFileVariantLoader();
      case "snp": return new SNPFileVariantLoader();
      default: return null;
    }
  }
  
  private static AbstractVariantLoader<?> chooseFormatBasedOnContent(File inputfile){
    AbstractVariantLoader<? extends ParsedEntry> loader = new MAFFileVariantLoader();
    if(loader.validateFormat(inputfile)){
      return loader;
    }
    loader = new MUTFileVariantLoader();
    if(loader.validateFormat(inputfile)){
      return loader;
    }
    loader = new VCFFileVariantLoader();
    if(loader.validateFormat(inputfile)){
      return loader;
    }
    loader = new SNPFileVariantLoader();
    if(loader.validateFormat(inputfile)){
      return loader;
    }
    return null;
  }
}
