/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.regions;

import at.icbi.gpviz.data.GPVChromosome;
import at.icbi.gpviz.data.GPVGene;
import at.tugraz.genome.biojava.seq.DNAStrand;


public class GPVVariant extends GPVHighlightedRegion
{
  
  private GPVVariantType variantType;
  private String dbSNPID;
  private String originalVariantType;
  
  public GPVVariant(GPVChromosome chromosome, int position, DNAStrand strand){
    super(chromosome,position,position,strand);
  }
  
  public GPVVariant(GPVChromosome chromosome, int position){
    super(chromosome,position,position,DNAStrand.UNKNOWN);
  }

  public GPVVariantType getVariantType()
  {
    return variantType;
  }
  
  public String getVariantTypeString(boolean forceOriginal)
  {
    if(forceOriginal || getVariantType()==null){
      return this.originalVariantType;
    }
    return GPVVariantConstants.getStringForVariantClassification(variantType);
  }

  public void setVariantType(GPVVariantType variantType)
  {
    this.variantType = variantType;
  }
  
  public String getDbSNPID()
  {
    return dbSNPID;
  }

  public void setDbSNPID(String dbSNPID)
  {
    this.dbSNPID = dbSNPID;
  }
  
  public String getOriginalVariantType()
  {
    return originalVariantType;
  }

  public void setOriginalVariantType(String originalVariantType)
  {
    this.originalVariantType = originalVariantType;
  }

  @Override
  public boolean isInGene(GPVGene gene){
    int chrom_compare = getChromosome().compareTo(gene.getChromosome());

    if(chrom_compare==0){
      boolean inrange = getStart() >= gene.getFirstKnownPosition() && getStop()<=gene.getLastKnownPosition();
      if(inrange){
        return true;
      }
    }
    return false;
  }
  
  public boolean equals(GPVVariant v){
    if(super.equals(v)){
      if( v.variantType.equals(variantType)){
        return true;
      }
    }
    return false;
  }
  @Override
  public int hashCode(){
    if(getVariantType()!=null){
      return (getChromosome().getTrimmedName()+getStart()+getStop()+getStrand()+getVariantType().getName()).hashCode();
    }else{
      return (getChromosome().getTrimmedName()+getStart()+getStop()+getStrand()+getOriginalVariantType()).hashCode();
    }
  }
}
