/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.regions;

import java.util.HashMap;
import java.util.Map.Entry;

import at.icbi.gpviz.data.regions.GPVVariantType.CLASS;
import at.icbi.gpviz.data.regions.GPVVariantType.TYPE;


public class GPVVariantConstants
{  
  
  public static GPVVariantType Frame_Shift_Insertion = new GPVVariantType(TYPE.INS, CLASS.Frame_Shift, "Frame Shift Insertion");
  public static GPVVariantType In_Frame_Insertion = new GPVVariantType(TYPE.INS, CLASS.In_Frame, "In Frame Insertion");
  public static GPVVariantType Frame_Shift_Deletion = new GPVVariantType(TYPE.DEL, CLASS.Frame_Shift, "Frame Shift Deletion");
  public static GPVVariantType In_Frame_Deletion = new GPVVariantType(TYPE.DEL, CLASS.In_Frame, "In Frame Deletion");
  public static GPVVariantType Missense_SNP = new GPVVariantType(TYPE.SNP, CLASS.Missense_Mutation, "Missense SNP");
  public static GPVVariantType Silent_SNP = new GPVVariantType(TYPE.SNP, CLASS.Silent, "Silent SNP");
  public static GPVVariantType Nonsense_SNP = new GPVVariantType(TYPE.SNP, CLASS.Nonsense_Mutation, "Nonsense SNP");
  public static GPVVariantType Other = new GPVVariantType(TYPE.Other, CLASS.Other, "Other");
  
  private static HashMap<String,GPVVariantType> variantClassificationStrings = null;
  
  private static HashMap<String,GPVVariantType> getStrings(){
    if(variantClassificationStrings == null){
      variantClassificationStrings =  new HashMap<String,GPVVariantType>();
      variantClassificationStrings.put(Frame_Shift_Insertion.getName(), Frame_Shift_Insertion);
      variantClassificationStrings.put(In_Frame_Insertion.getName(), In_Frame_Insertion);
      variantClassificationStrings.put(Frame_Shift_Deletion.getName(), Frame_Shift_Deletion);
      variantClassificationStrings.put(In_Frame_Deletion.getName(), In_Frame_Deletion);
      variantClassificationStrings.put(Missense_SNP.getName(), Missense_SNP);
      variantClassificationStrings.put(Silent_SNP.getName(), Silent_SNP);
      variantClassificationStrings.put(Nonsense_SNP.getName(), Nonsense_SNP);
      variantClassificationStrings.put(Other.getName(), Other);
    }
    return variantClassificationStrings;
  }
  
  public static String getStringForVariantClassification(GPVVariantType c){
    for(Entry<String, GPVVariantType> entry:getStrings().entrySet()){
      if(entry.getValue().equals(c)){
        return entry.getKey();
      }
    }
    return null;
  }
  
  public static GPVVariantType getVariantClassificationForString(String c){
    return getStrings().get(c);
  }
  
  
  public static CLASS getVariantClassificationByName(String name){
    return Enum.valueOf(CLASS.class, name);
  }
  
  public static TYPE getVariantTypeByName(String name){
    return Enum.valueOf(TYPE.class, name);
  }
}
