/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.regions;


public final class GPVVariantType
{
  public enum TYPE {
    SNP,
    INS, 
    DEL, 
    Other 
  }

  public enum CLASS{
    Frame_Shift,
    In_Frame, 
    Missense_Mutation, 
    Silent, 
    Nonsense_Mutation, 
    Other
  }
  
  
  private CLASS classification;
  private TYPE type;
  
  private String name;
  
  public GPVVariantType(TYPE type, CLASS classification, String name){
    this.classification = classification;
    this.type = type;
    this.name = name;
  }

  public CLASS getClassification()
  {
    return classification;
  }

  public TYPE getType()
  {
    return type;
  }
  
  public String getName()
  {
    return name;
  }

  public boolean equals(GPVVariantType v){
    if(this==v)return true;
    return (v.classification==this.classification && this.type == v.type); 
  }
  
  @Override
  public int hashCode(){
    return classification.hashCode()+type.hashCode();
  }
}
