/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.sorting;


import at.icbi.gpviz.data.GPVGene;

public class AlphabeticalGeneSorter extends GeneSorter
{

  protected GPVGene.DISPLAYNAME by;
  
  public AlphabeticalGeneSorter(GPVGene.DISPLAYNAME by, boolean descending){
    super(descending);
    this.by = by;
  }
  
  @Override
  public int compareImpl(GPVGene o1, GPVGene o2)
  {
    int comp = 0;
    switch(by){
      case ID:
        comp =  o1.getGeneID().compareTo(o2.getGeneID());
        break;
      case LONGNAME: 
        if(o1.getGeneFullName()!=null){
          comp =  o1.getGeneFullName().compareTo(o2.getGeneFullName());
          break;
        }
      case SYMBOL: 
        if(o1.getGeneSymbol()!=null && o2.getGeneSymbol()!=null){
          comp =  o1.getGeneSymbol().compareTo(o2.getGeneSymbol());
          break;
        }
      default:
        comp =  o1.getDisplayName().compareTo(o2.getDisplayName());
        break;
    }
    
    if(comp!=0)return comp;
    comp = o1.getGeneID().compareTo(o2.getGeneID());
    return comp;
  }

}
