/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.util;

public class MiniGlobMatcher
{
  private String[] parts;
  private boolean startsWildcard = false;
  private boolean endsWildcard = false;
  private boolean caseSensitive = false;
  
  public MiniGlobMatcher(String pattern, boolean casesensitive){
    this.parts = pattern.split("\\*");
    this.startsWildcard = pattern.startsWith("*");
    this.endsWildcard = pattern.endsWith("*");
    this.caseSensitive = casesensitive;
    if(!casesensitive){
      for(int i = 0; i < parts.length; i++){
        parts[i] = parts[i].toLowerCase();
      }
    }
  }
  
  public boolean matches(String tomatch){
    if(!caseSensitive){
      tomatch = tomatch.toLowerCase();
    }
    boolean ret = true;
    int index = 0;
    if(!startsWildcard && !endsWildcard && parts.length==1){
      return tomatch.startsWith(parts[0]);
    }
    
    if(!startsWildcard){
      if(!tomatch.startsWith(parts[0])){
        //if there is no wildcard at first, and it doesn't start with the first part
        //there is no need for further checking
        return false;
      }
    }
    
    if(parts.length>1 && !endsWildcard){
      if(!tomatch.endsWith(parts[parts.length-1])){
        //if there is no wildcard at the end, and it doesn't end with the last part
        //there is no need for further checking
        return false;
      }
    }
    int last_part_length = 0;
    for(int i=0; i< parts.length; i++ ){
      index = tomatch.indexOf(parts[i], index+last_part_length);
      last_part_length = parts[i].length();
      if(index == -1) {
        return false;
      }
    }
    return ret;
  }

}
