/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.data.util;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import javax.swing.JTable;
import javax.swing.table.TableModel;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVOptions;
import at.tugraz.genome.biojava.io.dsv.DSVEntry;
import at.tugraz.genome.biojava.io.dsv.writer.DSVOutputStream;

public class TableWriter
{

  public void writeTable(JTable table){
    GPVOptions opts = GPViz.getInstance().getOptions();
    String dir = opts.getLastImageSaveDir();
    JFileChooser chooser = new JFileChooser(dir);
    chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
    chooser.setDialogType(JFileChooser.SAVE_DIALOG);
    int result = chooser.showSaveDialog(null);
    if(result==JFileChooser.APPROVE_OPTION){
      File of = chooser.getSelectedFile();
      if(of!=null){
        opts.setLastImageSaveDir(of.getParent());
        GPVOptions.save(opts);
        FileOutputStream fos = null;
        DSVOutputStream<DSVEntry> os = null;

        try{
          fos = new FileOutputStream(of);
          os = new DSVOutputStream<DSVEntry>(fos);

          TableModel model = table.getModel();
          int cols = model.getColumnCount();
          int rows = model.getRowCount();

          String[] header = new String[cols];
          for(int col = 0; col < cols; col++){
            header[col] = model.getColumnName(col);
          }
          os.write(header);

          for(int row = 0; row<rows; row++){
            String[] rowdata = new String[cols];
            for(int col = 0; col < cols; col++){
              Object value =  model.getValueAt(row, col);
              String stringvalue = value!=null ? value.toString() : "";
              rowdata[col] = stringvalue;
            }
            os.write(rowdata);
          }
          
          JOptionPane.showMessageDialog(null, "Table saved successfully.");


        }catch(IOException io){
          JOptionPane.showMessageDialog(null, "Error writing output file. "+io.getMessage());
          io.printStackTrace();
        }finally{
          try{
            if(os!=null) os.close();
            if(fos!=null)fos.close();
          }catch(IOException io){
            io.printStackTrace();
          }
        }
      }
    }
  }
}
