/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.colorscheme;

import java.awt.Color;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

public abstract class AbstractGPVColorScheme implements GPVColorScheme
{

  public UserDefinedGPVColorScheme clone(){
    UserDefinedGPVColorScheme ret = new UserDefinedGPVColorScheme();
    
    ret.setDomainSetColors(this.getDomainSetColorProvider().getColors());
    
    Method[] methods = GPVColorScheme.class.getMethods();
    
    for(Method getter:methods){
      if(getter.isAnnotationPresent(GPVColor.class)){
        if(getter.getName().startsWith("get") && getter.getReturnType()==Color.class){
          //find the proper setter
          String settername = "set"+getter.getName().substring(3);
          try
          {
            Method setter = ret.getClass().getMethod(settername, new Class[]{Color.class});
            Color color = (Color) getter.invoke(this, (Object[]) null);
            if(color!=null){
              setter.invoke(ret, color);
            }
          }
          catch (NoSuchMethodException e)
          {
            System.err.println("Reflection error finding setter method "+settername+" in "+ret.getClass().getName());
            e.printStackTrace();
          }
          catch (SecurityException e)
          {
            System.err.println("Reflection error finding setter method "+settername+" in "+ret.getClass().getName());
            e.printStackTrace();
          }
          catch (IllegalAccessException e)
          {
            System.err.println("Reflection error invoking " + getter.getName()+ " in "+this.getClass().getName());
            e.printStackTrace();
          }
          catch (IllegalArgumentException e)
          {
            System.err.println("Reflection error invoking " + getter.getName()+ " in "+this.getClass().getName());
            e.printStackTrace();
          }
          catch (InvocationTargetException e)
          {
            System.err.println("Reflection error invoking " + getter.getName()+ " in "+this.getClass().getName());
            e.printStackTrace();
          }  
        }
      }
    }
    
    return ret;
  }
  
  
  @Override
  public String toString(){
    return getName();
  }
  
}
