/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.colorscheme;

import java.awt.Color;
import java.util.ArrayList;


public class DefaultGPVColorScheme extends AbstractGPVColorScheme
{

  public static final String NAME = "Default Color Scheme";
  
  @Override
  public Color getExonFill()
  {
    return Color.getHSBColor(97f/360f, 0.5f, 0.93f);
  }

  @Override
  public Color getIntronFill()
  {
    return Color.getHSBColor(95f/360f, 0.15f, 1f);
  }
  
  @Override
  public Color getTranscriptFill()
  {
    return Color.getHSBColor(309/360f, 0.27f, 0.89f);
  }

  @Override
  public Color getProteinFill()
  {
    return Color.getHSBColor(34f/360f, 0.5f, 0.93f);
  }

  @Override
  public Color getBlockBorder()
  {
    return Color.getHSBColor(1f, 0f, 0f);
  }

  @Override
  public Color getStopCodon()
  {
    return Color.getHSBColor(1f, 0.7f, 1f);
  }
  
  @Override
  public Color getStartCodon()
  {
    return Color.getHSBColor(0.75f, 0.7f, 1f);
  }

  @Override
  public Color getGuidelines()
  {
    return Color.getHSBColor(1f, 0f, 0.6f);
  }

  @Override
  public Color getTranscriptRails()
  {
    return Color.getHSBColor(1f, 0f, 0f);
  }

  @Override
  public Color getDomainOverlapHighlighterFill()
  {
    return Color.getHSBColor(1/360f, 0.80f, 1f);
  }
  
  @Override
  public Color getSNPDomainOverlapHighlighterFill()
  {
    return Color.getHSBColor(1/360f, 0.80f, 0.8f);
  }
  
  @Override
  public Color getHighlighterColor(){
    return Color.getHSBColor(60/360f, 0.8f, 1f);
  }

  @Override
  public Color getSNPHighlighterColor()
  {
    return Color.getHSBColor(60/360f, 0.8f, 0.8f);
  }
  
  @Override
  public Color getMergeSiteMarkerColor()
  {
    return Color.red;
  }

  @Override
  public Color getUnionTranscriptFill()
  {
    return Color.getHSBColor(309/360f, 0.68f, 0.78f);
  }

  @Override
  public Color getUnionProteinFill()
  {
    return Color.getHSBColor(34f/360f, 1.0f, 0.8f);
  }

  @Override
  public Color getTitleColor(){
    return Color.black;
  }

  @Override
  public Color getCanvasBackground(){
    return Color.white;
  }
  
  @Override
  public ColorProvider getDomainSetColorProvider()
  {
    ArrayList<Color> colors = new ArrayList<Color>();
    colors.add(Color.getHSBColor(200f/360f, 1f, 1f));
    colors.add(Color.getHSBColor(80f/360f, 1f, 1f));
    colors.add(Color.getHSBColor(320f/360f, 1f, 1f));
    colors.add(Color.getHSBColor(240f/360f, 1f, 1f));
    colors.add(Color.getHSBColor(120f/360f, 1f, 1f));
    colors.add(Color.getHSBColor(280f/360f, 1f, 1f));
    
    colors.add(Color.getHSBColor(25f/360f, 0.9f, 0.95f));
    colors.add(Color.getHSBColor(220f/360f, 0.7f, 0.8f));
    colors.add(Color.getHSBColor(140f/360f, 0.8f, 0.8f));
    colors.add(Color.getHSBColor(310f/360f, 0.6f, 0.9f));
    colors.add(Color.getHSBColor(180f/360f, 0.8f, 0.8f));
    colors.add(Color.getHSBColor(100f/360f, 0.8f, 0.8f));
    colors.add(Color.getHSBColor(260f/360f, 0.7f, 0.7f));
    
    return new ColorProvider(colors.toArray(new Color[0]));
  }

  @Override
  public String getName()
  {
    return NAME;
  }

  @Override
  public Color getTopIntronRegionHighlighter()
  {
    return Color.getHSBColor(1f, 0f, 0.5f);
  }

  @Override
  public Color getTopExonRegionHighlighter()
  {
    return Color.getHSBColor(1f, 0f, 0.35f);    
  }

  @Override
  public Color getLassoHighlighterColor()
  {
    return Color.orange;
  }

}
