/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.colorscheme;

import java.awt.Color;


public interface GPVColorScheme
{
  @GPVColor(description="Exon block fill")
  public Color getExonFill();
  @GPVColor(description="Intron block fill")
  public Color getIntronFill();
  @GPVColor(description="Transcript block fill")
  public Color getTranscriptFill();
  @GPVColor(description="Union transcript block fill")
  public Color getUnionTranscriptFill();
  @GPVColor(description="Protein block fill")
  public Color getProteinFill();
  @GPVColor(description="Union protein block fill")
  public Color getUnionProteinFill();
  
  @GPVColor(description="Main region highlighter")
  public Color getHighlighterColor();
  
  @GPVColor(description="Main SNP highlighter", failover="getHighlighterColor")
  public Color getSNPHighlighterColor();
  
  @GPVColor(description="Highlighter for regions in domains")
  public Color getDomainOverlapHighlighterFill();
  
  @GPVColor(description="Highlighter for SNPs in domains", failover="getDomainOverlapHighlighterFill")
  public Color getSNPDomainOverlapHighlighterFill();
  
  @GPVColor(description="Interactive lasso highlighter")
  public Color getLassoHighlighterColor();
  
  @GPVColor(description="Stop codon marker")
  public Color getStopCodon();
  @GPVColor(description="Start codon marker")
  public Color getStartCodon();

  @GPVColor(description="Exon split sites marker on gene")
  public Color getMergeSiteMarkerColor();
  
  @GPVColor(description="Canvas background")
  public Color getCanvasBackground();
  
  @GPVColor(description="Title text color")
  public Color getTitleColor();
  
  @GPVColor(description="Highlighter for intron regions on the gene")
  public Color getTopIntronRegionHighlighter();
  
  @GPVColor(description="Highlighter for exon regions on the gene")
  public Color getTopExonRegionHighlighter();
  
  @GPVColor(description="Block borders")
  public Color getBlockBorder();
  
  @GPVColor(description="Guidelines")
  public Color getGuidelines();
  @GPVColor(description="Transcript rails")
  public Color getTranscriptRails();
  
  
  public ColorProvider getDomainSetColorProvider();
  public String getName();
}


