/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.colorscheme;

import java.awt.Color;
import java.io.File;
import java.io.FileFilter;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Method;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JOptionPane;
import javax.xml.bind.JAXB;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import at.icbi.gpviz.xml.RGBColorAdapter;

public class UserDefinedGPVColorScheme extends AbstractGPVColorScheme
{
  private Color exonFill; 
  private Color intronFill; 
  private Color transcriptFill; 
  private Color proteinFill; 
  private Color domainOverlapHighlighterFill;
  private Color snpDomainOverlapHighlighterFill;
  private Color blockBorder; 
  private Color topIntronRegionHighlighter; 
  private Color topExonRegionHighlighter; 
  private Color stopCodon; 
  private Color startCodon; 
  private Color guidelines; 
  private Color transcriptRails; 
  private Color highlighterColor;
  private Color snpHighlighterColor;
  private Color lassoHighlighterColor;
  private Color mergeSiteMarkerColor; 
  private Color unionTranscriptFill; 
  private Color unionProteinFill; 
  private Color titleColor;
  private Color canvasBackground; 
  
  private Color[] domainSetColors;
  
  private String name;
  private String oldName;

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getExonFill()
  {
    return exonFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getIntronFill()
  {
    return intronFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getTranscriptFill()
  {
    return transcriptFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getProteinFill()
  {
    return proteinFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getDomainOverlapHighlighterFill()
  {
    return domainOverlapHighlighterFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getBlockBorder()
  {
    return blockBorder;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getStopCodon()
  {
    return stopCodon;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getStartCodon()
  {
    return startCodon;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getGuidelines()
  {
    return guidelines;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getTranscriptRails()
  {
    return transcriptRails;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getHighlighterColor()
  {
    return highlighterColor;
  }
  

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getSNPHighlighterColor()
  {
    return snpHighlighterColor;
  }
  

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getMergeSiteMarkerColor()
  {
    return mergeSiteMarkerColor;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getUnionTranscriptFill()
  {
    return unionTranscriptFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getUnionProteinFill()
  {
    return unionProteinFill;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getTitleColor()
  {
    return titleColor;
  }

  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getTopIntronRegionHighlighter()
  {
    return topIntronRegionHighlighter;
  }
  
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getTopExonRegionHighlighter()
  {
    return topExonRegionHighlighter;
  }
  
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getCanvasBackground()
  {
    return canvasBackground;
  }
  
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color[] getDomainSetColors()
  {
    return domainSetColors;
  }

  public void setDomainSetColors(Color[] domainSetColors)
  {
    this.domainSetColors = domainSetColors;
  }

  @Override
  @XmlTransient
  public ColorProvider getDomainSetColorProvider()
  {
    if(domainSetColors==null || domainSetColors.length==0){
      return new DefaultGPVColorScheme().getDomainSetColorProvider();
    }
    return new ColorProvider(domainSetColors);
  }

  public void setExonFill(Color exonFill)
  {
    this.exonFill = exonFill;
  }

  public void setIntronFill(Color intronFill)
  {
    this.intronFill = intronFill;
  }

  public void setTranscriptFill(Color transcriptFill)
  {
    this.transcriptFill = transcriptFill;
  }

  public void setProteinFill(Color proteinFill)
  {
    this.proteinFill = proteinFill;
  }

  public void setDomainOverlapHighlighterFill(Color domainOverlapHighlighterFill)
  {
    this.domainOverlapHighlighterFill = domainOverlapHighlighterFill;
  }
  
  public void setSNPDomainOverlapHighlighterFill(Color domainOverlapHighlighterFill)
  {
    this.snpDomainOverlapHighlighterFill = domainOverlapHighlighterFill;
  }

  public void setBlockBorder(Color blockBorder)
  {
    this.blockBorder = blockBorder;
  }

  public void setStopCodon(Color stopCodon)
  {
    this.stopCodon = stopCodon;
  }

  public void setStartCodon(Color startCodon)
  {
    this.startCodon = startCodon;
  }

  public void setGuidelines(Color guidelines)
  {
    this.guidelines = guidelines;
  }

  public void setTranscriptRails(Color transcriptRails)
  {
    this.transcriptRails = transcriptRails;
  }

  public void setHighlighterColor(Color highlighterColor)
  {
    this.highlighterColor = highlighterColor;
  }
  
  public void setSNPHighlighterColor(Color highlighterColor)
  {
    this.snpHighlighterColor = highlighterColor;
  }

  public void setMergeSiteMarkerColor(Color mergeSiteMarkerColor)
  {
    this.mergeSiteMarkerColor = mergeSiteMarkerColor;
  }

  public void setUnionTranscriptFill(Color unionTranscriptFill)
  {
    this.unionTranscriptFill = unionTranscriptFill;
  }

  public void setUnionProteinFill(Color unionProteinFill)
  {
    this.unionProteinFill = unionProteinFill;
  }

  public void setTitleColor(Color titleColor)
  {
    this.titleColor = titleColor;
  }
  
  public void setCanvasBackground(Color bg)
  {
    this.canvasBackground = bg;
  }

  public String getName()
  {
    return name;
  }

  public void setName(String name)
  {
    if(this.name==null) oldName = name;
    this.name = name;
  }
  
  public void setTopIntronRegionHighlighter(Color topIntronRegionHighlighter)
  {
    this.topIntronRegionHighlighter = topIntronRegionHighlighter;
  }

  public void setTopExonRegionHighlighter(Color topExonRegionHighlighter)
  {
    this.topExonRegionHighlighter = topExonRegionHighlighter;
  }

  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getLassoHighlighterColor()
  {
    return lassoHighlighterColor;
  }
  
  public void setLassoHighlighterColor(Color lassoHilighterColor){
    this.lassoHighlighterColor = lassoHilighterColor;
  }
  
  @Override
  @XmlJavaTypeAdapter(RGBColorAdapter.class)
  public Color getSNPDomainOverlapHighlighterFill()
  {
    return snpDomainOverlapHighlighterFill;
  }
  
  
  
  
  public static String createFilename(String name){
    try
    {
      name = URLEncoder.encode(name, "UTF-8");
    }
    catch (UnsupportedEncodingException e)
    {
      e.printStackTrace();
    }
    return System.getProperty("user.home")+"/.gpviz/"+name+"-colorscheme.xml";
  }
  
  public static List<UserDefinedGPVColorScheme> loadAll(){
    ArrayList<UserDefinedGPVColorScheme> ret = new ArrayList<UserDefinedGPVColorScheme>();
    File folder = new File(System.getProperty("user.home")+"/.gpviz/");
    if(folder.exists()){
      File[] subfiles = folder.listFiles(new FileFilter()
      {
        @Override public boolean accept(File pathname)
        {
          return pathname.isFile() && pathname.getName().endsWith("colorscheme.xml");
        }
      });
      
      for(File file:subfiles){
        UserDefinedGPVColorScheme colors = load(file);
        if(colors!=null){
          ret.add(colors);
        }
      }
    }
    return ret;
  }
  
  public static UserDefinedGPVColorScheme load(File savefile){
    UserDefinedGPVColorScheme ret = null;
    if(!savefile.exists()){
      return ret;
    }
    
    try{
      ret = JAXB.unmarshal(savefile, UserDefinedGPVColorScheme.class);
      ret.fillEmptyColors();
    }catch(Exception e){
      e.printStackTrace();
      JOptionPane.showMessageDialog(null, "Error loading options file "+savefile.getName());
    }
    return ret;
  }  
  
  public static void save(UserDefinedGPVColorScheme colors){
    if(colors.oldName!=null){
      if(!colors.oldName.equals(colors.name)){
        File deletefile = new File(createFilename(colors.oldName));
        deletefile.delete();
      }
    }
    colors.oldName = colors.name;
    
    File savefile = new File(createFilename(colors.getName()));
    if(!savefile.getParentFile().exists()) savefile.getParentFile().mkdirs();
    
    JAXB.marshal(colors, savefile);
  }
  
  /**
   * Useful when old saved color schemes are missing new colors 
   */
  public void fillEmptyColors(){
    Method[] methods = GPVColorScheme.class.getMethods();
    DefaultGPVColorScheme defaultScheme = new DefaultGPVColorScheme();  
    for(Method getter:methods){
      if(getter.isAnnotationPresent(GPVColor.class)){
        if(getter.getName().startsWith("get") && getter.getReturnType()==Color.class){
          //find the proper setter
          String settername = "set"+getter.getName().substring(3);
          try
          {
            Method setter = getClass().getMethod(settername, new Class[]{Color.class});
            String failover_color_getter = getter.getAnnotation(GPVColor.class).failover();
            Color defcolor = null;
            if(!failover_color_getter.equals("")){
              try{
                Method failover_getter = GPVColorScheme.class.getMethod(failover_color_getter,new Class[]{});
                defcolor = (Color) failover_getter.invoke(this, new Object[]{});
              }catch(ReflectiveOperationException e){
                e.printStackTrace();
              }
            }
            
            if(defcolor==null){
              //either there is no failover color for this one, or retrieving it failed. Let's use the one from the default scheme instead 
              defcolor = (Color) getter.invoke(defaultScheme, (Object[]) null);
            }
            
            Color color = (Color) getter.invoke(this, (Object[]) null);
            if(color==null && defcolor!=null){
              setter.invoke(this, defcolor);
            }
          }
          catch (ReflectiveOperationException e)
          {
            System.err.println("Reflection error finding setter method "+settername+" in "+getClass().getName());
            e.printStackTrace();
          }
          catch (SecurityException e)
          {
            System.err.println("Reflection error finding setter method "+settername+" in "+getClass().getName());
            e.printStackTrace();
          }
          catch (IllegalArgumentException e)
          {
            System.err.println("Reflection error invoking " + getter.getName()+ " in "+defaultScheme.getClass().getName());
            e.printStackTrace();
          }
        }
      }
    }
  }
  
  public static void delete(UserDefinedGPVColorScheme colors){
    if(colors.oldName!=null){
        File deletefile = new File(createFilename(colors.oldName));
        deletefile.delete();
    }
  }
}
