/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes;

import java.util.Collection;
import java.util.HashMap;

import at.icbi.gpviz.data.regions.GPVVariant;
import at.icbi.gpviz.data.regions.GPVVariantConstants;
import at.icbi.gpviz.data.regions.GPVVariantType;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeCircle;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeDiamond;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeSquare;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeTriangle;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeUSDTriangle;

public class DefaultGPVVariantShapeScheme implements GPVVariantShapeScheme
{

  private HashMap<String,GPVVariantShape> map;
  
  public DefaultGPVVariantShapeScheme(){
    map = new HashMap<String,GPVVariantShape>();
    map.put(GPVVariantConstants.Frame_Shift_Deletion.getName(), new GPVShapeDiamond(true));
    map.put(GPVVariantConstants.In_Frame_Deletion.getName(), new GPVShapeDiamond(false));
    map.put(GPVVariantConstants.Frame_Shift_Insertion.getName(), new GPVShapeTriangle(true));
    map.put(GPVVariantConstants.In_Frame_Insertion.getName(), new GPVShapeTriangle(false));
    map.put(GPVVariantConstants.Missense_SNP.getName(), new GPVShapeUSDTriangle(true));
    map.put(GPVVariantConstants.Silent_SNP.getName(), new GPVShapeUSDTriangle(false));
    map.put(GPVVariantConstants.Nonsense_SNP.getName(), new GPVShapeCircle(true));
    map.put(GPVVariantConstants.Other.getName(), new GPVShapeSquare(true));
  }
  
  @Override
  public GPVVariantShape getShapeFor(GPVVariantType variant)
  {
    if(variant==null){
      return null;
    }
    return getShapeFor(variant.getName());
  }

  @Override
  public GPVVariantShape getShapeFor(String type)
  {
    GPVVariantShape ret = map.get(type);
//    if(ret==null)ret = map.get(GPVVariantConstants.Other);
    return ret;
  }
  
  @Override
  public GPVVariantShape getShapeFor(GPVVariant variant)
  {
    return getShapeFor(variant.getVariantType());
  }

  @Override
  public Collection<GPVVariantShape> getPossibleShapes()
  {
    return map.values();
  }


}
