/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;

import at.icbi.gpviz.data.regions.GPVVariant;
import at.icbi.gpviz.data.regions.GPVVariantConstants;
import at.icbi.gpviz.data.regions.GPVVariantType;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeCircle;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeDiamond;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapePentagon;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapePlus;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeStar;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeTriangle;
import at.icbi.gpviz.drawing.variantshapes.shapes.GPVShapeUSDTriangle;

public class DynamicGPVVariantShapeScheme implements GPVVariantShapeScheme
{

  private HashMap<String,GPVVariantShape> map;
  private GPVVariantShapeScheme known_shape_scheme;

  public DynamicGPVVariantShapeScheme(Collection<String> variant_types, GPVVariantShapeScheme known_shape_scheme){
    this.known_shape_scheme = known_shape_scheme;

    GPVVariantShape[] all_shapes = new GPVVariantShape[]{new GPVShapeTriangle(true),
        new GPVShapeDiamond(true),
        new GPVShapeUSDTriangle(true),
        new GPVShapeCircle(true),
        new GPVShapePentagon(true),
        new GPVShapePlus(true),
        new GPVShapeStar(true),
        new GPVShapeTriangle(false),
        new GPVShapeDiamond(false),
        new GPVShapeUSDTriangle(false),
        new GPVShapeCircle(false),
        new GPVShapePentagon(false),
        new GPVShapePlus(false),
        new GPVShapeStar(false)};
    
    ArrayList<GPVVariantShape> left = new ArrayList<GPVVariantShape>();
    for(int i =0; i < all_shapes.length; i++){
      boolean contains = false;
      for(GPVVariantShape comp : known_shape_scheme.getPossibleShapes()){
        if(comp.equals(all_shapes[i])){
          contains = true;
        }
      }
      
      if(!contains){
        left.add(all_shapes[i]); 
      }
    }
    
    GPVVariantShape[] to_use = left.toArray(new GPVVariantShape[0]);
    
    map = new HashMap<String,GPVVariantShape>();
    int i = 0; 
    for(String type:variant_types){
      map.put(type, to_use[i]);
      i++;
      if(i>=to_use.length) i=0;
    }

  }

  @Override
  public GPVVariantShape getShapeFor(GPVVariantType type)
  {
    GPVVariantShape ret = known_shape_scheme.getShapeFor(type);
    if(ret==null){
      ret = getShapeFor(type.getName());
    }
    return ret;
  }

  @Override
  public GPVVariantShape getShapeFor(String type)
  {
    GPVVariantShape ret = known_shape_scheme.getShapeFor(type);
    if(ret==null){
      ret = map.get(type);
      if(ret==null)ret = known_shape_scheme.getShapeFor(GPVVariantConstants.Other);
    }
    return ret;
  }

  @Override
  public GPVVariantShape getShapeFor(GPVVariant variant)
  {
    GPVVariantShape ret = known_shape_scheme.getShapeFor(variant);
    if(ret==null){
      ret = getShapeFor(variant.getOriginalVariantType());
    }
    return ret;
  }

  @Override
  public Collection<GPVVariantShape> getPossibleShapes()
  {
    return map.values();
  }

}
