/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes;

import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;

import at.icbi.gpviz.drawing.variantshapes.shapes.GPVWrapperShape;

public abstract class GPVVariantShape implements Shape
{

  protected Point2D top_anchor;
  protected Point2D bottom_anchor;
  protected double height;
  protected double width;
  
  protected boolean filled;
  
  
  public GPVVariantShape(boolean filled){
    this.filled = filled;
  }
  
  public void init(Point2D top_anchor, Point2D bottom_anchor, double height, double width){
    this.top_anchor = top_anchor;
    this.bottom_anchor = bottom_anchor;
    this.height = height;
    this.width = width;
  }
  public void init(Point2D top_anchor, double height, double width){
    this.top_anchor = top_anchor;
    this.height = height;
    this.width = width;
  }
  
  
  public abstract String getName();
  
  public abstract Point2D getLineAnchor();
  
  @Override
  public Rectangle getBounds()
  {
    return new Rectangle((int)(top_anchor.getX()-width/2d),(int)top_anchor.getY(),(int)width,(int)height);
  }

  @Override
  public Rectangle2D getBounds2D()
  {
    return new Rectangle2D.Double(top_anchor.getX()-width/2d,top_anchor.getY(),width,height);
  }

  public boolean isSupposedToBeFilled(){
    return this.filled;
  }
  
  public boolean equals(GPVVariantShape shape){
    return (shape.getClass() == this.getClass() && shape.filled==this.filled);
  }
}
