/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes.shapes;

import java.awt.Shape;
import java.awt.geom.Point2D;

import org.apache.batik.ext.awt.geom.Polygon2D;

public class GPVShapePlus extends GPVWrapperShape
{
  public GPVShapePlus(boolean filled){
    super(filled);
  }
  
  @Override
  protected Shape createShape()
  {
    double inset = width*0.2d;
    float left = (float)(top_anchor.getX()-(width/2d));
    float right = (float) (top_anchor.getX()+(width/2d));
    double center = top_anchor.getX();
    float top = (float) top_anchor.getY();
    float bottom = (float)(top_anchor.getY()+height);
    double middle = top_anchor.getY()+(height/2d);
    
    float x1 = (float)(center-inset);
    float x2 = (float)(center+inset);
    float y1 = (float)(middle-inset);
    float y2 = (float)(middle+inset);
    
    float x[] = new float[]{x1,  x1, left, left, x1, x1,     x2,     x2, right, right, x2, x2 };
    float y[] = new float[]{top, y1, y1,   y2,   y2, bottom, bottom, y2, y2,    y1,    y1, top};
    return new Polygon2D(x, y, x.length);
  }

  @Override
  public String getName()
  {
    return "Plus";
  }
  
  @Override
  public Point2D getLineAnchor()
  {
    return new Point2D.Double(top_anchor.getX(), top_anchor.getY()+height);
  }
  
}
