/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes.shapes;

import java.awt.Shape;
import java.awt.geom.Point2D;

import org.apache.batik.ext.awt.geom.Polygon2D;

public class GPVShapeStar extends GPVWrapperShape
{
  public GPVShapeStar(boolean filled){
    super(filled);
  }
  
  @Override
  public Point2D getLineAnchor()
  {
    double y_off = height* Math.tan(Math.toRadians(36));
    return new Point2D.Double(top_anchor.getX(), top_anchor.getY()+y_off+1);
  }

  @Override
  protected Shape createShape()
  {
    float left = (float)(top_anchor.getX()-(width/2d));
    float right = (float) (top_anchor.getX()+(width/2d));
    double center = top_anchor.getX();
    float top = (float) top_anchor.getY();
    float bottom = (float)(top_anchor.getY()+height);
    double leg_spread = width* Math.tan(Math.toRadians(18));
    double y_off = height* Math.tan(Math.toRadians(36))/2d;
    
    Point2D cornertop = new Point2D.Double(center,top);
    Point2D cornerleft = new Point2D.Double(left,top+y_off);
    Point2D cornerlegleft = new Point2D.Double(center-leg_spread,bottom);
    Point2D cornerlegright = new Point2D.Double(center+leg_spread,bottom);
    Point2D cornerright = new Point2D.Double(right,top+y_off);
    
    Point2D inner1 = ShapeUtils.getLineIntersection(cornertop,cornerlegleft,cornerleft,cornerright);
    Point2D inner2 = ShapeUtils.getLineIntersection(cornerleft,cornerlegright,cornerlegleft,cornertop);
    Point2D inner3 = ShapeUtils.getLineIntersection(cornerlegleft,cornerright,cornerlegright,cornerleft);
    Point2D inner4 = ShapeUtils.getLineIntersection(cornerlegright,cornertop,cornerright,cornerlegleft);
    Point2D inner5 = ShapeUtils.getLineIntersection(cornerright,cornerleft,cornertop,cornerlegright);
    
    float x[] = new float[]{(float)cornertop.getX(),  (float)inner1.getX(), (float)cornerleft.getX(), (float)inner2.getX(), (float)cornerlegleft.getX(), 
        (float)inner3.getX(), (float)cornerlegright.getX(),(float)inner4.getX(),(float)cornerright.getX(), (float)inner5.getX()};
    float y[] = new float[]{(float)cornertop.getY(),  (float)inner1.getY(), (float)cornerleft.getY(), (float)inner2.getY(), (float)cornerlegleft.getY(), 
        (float)inner3.getY(), (float)cornerlegright.getY(),(float)inner4.getY(),(float)cornerright.getY(), (float)inner5.getY()};
    
    return new Polygon2D(x, y, x.length);
  }
  
  @Override
  public String getName()
  {
    return "Star";
  }
  
}
