/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes.shapes;

import java.awt.Shape;
import java.awt.geom.AffineTransform;
import java.awt.geom.PathIterator;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;

import at.icbi.gpviz.drawing.variantshapes.GPVVariantShape;

public abstract class GPVWrapperShape extends GPVVariantShape
{
  protected Shape wrapped;

  protected abstract Shape createShape();
  
  public GPVWrapperShape(boolean filled){
    super(filled);
  }
  
  @Override
  public void init(Point2D top_anchor, Point2D bottom_anchor, double height, double width){
    super.init(top_anchor,bottom_anchor, height,width);
    this.wrapped = createShape();
  }
  
  @Override
  public void init(Point2D top_anchor, double height, double width){
    super.init(top_anchor, height,width);
    this.wrapped = createShape();
  }

  @Override
  public boolean contains(double x, double y)
  {
    return wrapped.contains(x,y);
  }

  @Override
  public boolean contains(Point2D p)
  {
    return wrapped.contains(p);
  }

  @Override
  public boolean intersects(double x, double y, double w, double h)
  {
    return wrapped.intersects(x,y,w,h);
  }

  @Override
  public boolean intersects(Rectangle2D r)
  {
    return wrapped.intersects(r);
  }

  @Override
  public boolean contains(double x, double y, double w, double h)
  {
    return wrapped.contains(x,y,w,h);
  }

  @Override
  public boolean contains(Rectangle2D r)
  {
    return wrapped.contains(r);
  }

  @Override
  public PathIterator getPathIterator(AffineTransform at)
  {
    return wrapped.getPathIterator(at);
  }

  @Override
  public PathIterator getPathIterator(AffineTransform at, double flatness)
  {
    return wrapped.getPathIterator(at,flatness);
  }

  
}
