/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.drawing.variantshapes.shapes;

import java.awt.geom.Point2D;

public class ShapeUtils
{
  public static Point2D getLineIntersection(Point2D linea_p1, Point2D linea_p2, Point2D lineb_p1, Point2D lineb_p2) {
    return getLineIntersection(linea_p1.getX(),linea_p1.getY(), linea_p2.getX(),linea_p2.getY(), lineb_p1.getX(),lineb_p1.getY(), lineb_p2.getX(),lineb_p2.getY());
  }
  public static Point2D getLineIntersection(double x1, double y1, double x2, double y2, double x3, double y3, double x4, double y4) {
    double det1And2 = det(x1, y1, x2, y2);
    double det3And4 = det(x3, y3, x4, y4);
    double x1LessX2 = x1 - x2;
    double y1LessY2 = y1 - y2;
    double x3LessX4 = x3 - x4;
    double y3LessY4 = y3 - y4;
    double det1Less2And3Less4 = det(x1LessX2, y1LessY2, x3LessX4, y3LessY4);
    if (det1Less2And3Less4 == 0){
       // the denominator is zero so the lines are parallel and there's either no solution (or multiple solutions if the lines overlap) so return null.
       return null;
    }
    double x = (det(det1And2, x1LessX2,
          det3And4, x3LessX4) /
          det1Less2And3Less4);
    double y = (det(det1And2, y1LessY2,
          det3And4, y3LessY4) /
          det1Less2And3Less4);
    return new Point2D.Double(x, y);
 }
 protected static double det(double a, double b, double c, double d) {
    return a * d - b * c;
 }
}
