/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import at.icbi.gpviz.GPViz;

public class AboutDialog extends JDialog implements ActionListener, MouseListener
{

  private static final long serialVersionUID = -366284099477122637L;
  private final JPanel contentPanel = new JPanel();
  private JLabel lblNewLabel_2;
  private JButton okButton = new JButton("Close");
  private JTextArea citationTextArea = new JTextArea();

  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    try
    {
      AboutDialog dialog = new AboutDialog();
      dialog.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
      dialog.setVisible(true);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  /**
   * Create the dialog.
   */
  public AboutDialog(JFrame parent)
  {
    this();
    setModal(true);
    setLocationRelativeTo(parent);
  }
  
  /**
   * Create the dialog.
   */
  public AboutDialog()
  {
    setTitle("About");
    setBounds(100, 100, 500, 400);
    this.setMinimumSize(new Dimension(500,400));
    getContentPane().setLayout(new BorderLayout());
    contentPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
    getContentPane().add(contentPanel, BorderLayout.CENTER);
    SpringLayout sl_contentPanel = new SpringLayout();
    sl_contentPanel.putConstraint(SpringLayout.WEST, citationTextArea, 10, SpringLayout.WEST, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.SOUTH, citationTextArea, 0, SpringLayout.SOUTH, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.EAST, citationTextArea, -10, SpringLayout.EAST, contentPanel);
    contentPanel.setLayout(sl_contentPanel);
    {
      lblNewLabel_2 = new JLabel(GPViz.PROGRAM_NAME+" "+GPViz.VERSION+ " ("+GPViz.VERSION_DATE+")");
      lblNewLabel_2.setFont(new Font("Dialog", Font.BOLD, 16));
      sl_contentPanel.putConstraint(SpringLayout.NORTH, lblNewLabel_2, 10, SpringLayout.NORTH, contentPanel);
      sl_contentPanel.putConstraint(SpringLayout.WEST, lblNewLabel_2, 10, SpringLayout.WEST, contentPanel);
      contentPanel.add(lblNewLabel_2);
    }
    
    JLabel lblCitation = new JLabel("Cite as:");
    sl_contentPanel.putConstraint(SpringLayout.WEST, lblCitation, 0, SpringLayout.WEST, lblNewLabel_2);
    contentPanel.add(lblCitation);
    citationTextArea.setText(GPViz.CITATION);
    citationTextArea.addMouseListener(this);
    citationTextArea.setEditable(false);
    citationTextArea.setLineWrap(true);
    citationTextArea.setColumns(50);
    citationTextArea.setRows(4);
    citationTextArea.setWrapStyleWord(true);
    contentPanel.add(citationTextArea);
    
    JTextArea licenseTextArea = new JTextArea();
    licenseTextArea.setEditable(false);
    sl_contentPanel.putConstraint(SpringLayout.NORTH, citationTextArea, 26, SpringLayout.SOUTH, licenseTextArea);
    sl_contentPanel.putConstraint(SpringLayout.NORTH, lblCitation, 6, SpringLayout.SOUTH, licenseTextArea);
    sl_contentPanel.putConstraint(SpringLayout.NORTH, licenseTextArea, 5, SpringLayout.SOUTH, lblNewLabel_2);
    sl_contentPanel.putConstraint(SpringLayout.WEST, licenseTextArea, 10, SpringLayout.WEST, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.SOUTH, licenseTextArea, -148, SpringLayout.SOUTH, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.EAST, licenseTextArea, -10, SpringLayout.EAST, contentPanel);
    licenseTextArea.setLineWrap(true);
    licenseTextArea.setText("GPViz Copyright (C) 2013 Rene Snajder\nDivision of Bioinformatics, Biocenter\nInnsbruck Medical University\n\nThis program is licensed under GNU GPL 3.0. It comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under certain conditions. \n\nFor the full license text, visit: http://www.gnu.org/licenses/gpl-3.0.html");
    licenseTextArea.setBackground(contentPanel.getBackground());
    licenseTextArea.setColumns(50);
    licenseTextArea.setRows(4);
    licenseTextArea.setWrapStyleWord(true);
    contentPanel.add(licenseTextArea);
    {
      JPanel buttonPane = new JPanel();
      buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
      getContentPane().add(buttonPane, BorderLayout.SOUTH);
      {
        okButton.addActionListener(this);
        okButton.setActionCommand("OK");
        buttonPane.add(okButton);
        getRootPane().setDefaultButton(okButton);
      }
    }
  }

  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource()==okButton){
      this.setVisible(false);
    }
  }

  @Override
  public void mouseClicked(MouseEvent e)
  {
  }

  @Override
  public void mousePressed(MouseEvent e)
  {    
  }

  @Override
  public void mouseReleased(MouseEvent e)
  {
  }

  @Override
  public void mouseEntered(MouseEvent e)
  {
  }

  @Override
  public void mouseExited(MouseEvent e)
  {
  }
}
