/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.File;
import java.util.ArrayList;
import java.util.Collection;

import javax.swing.Box;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JTextField;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;
import javax.swing.filechooser.FileFilter;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.drawing.GPVImageWriter;
import at.icbi.gpviz.swing.canvas.CanvasProperties;
import at.tugraz.genome.util.FileUtils;
import at.tugraz.genome.util.ProgressListener;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;

public class BatchImageSaveDialog extends JDialog implements ActionListener, ProgressListener, ItemListener
{

  private boolean oneFile = false; 
  
  private static final long serialVersionUID = 5229535929054241898L;
  private final JPanel topPanel = new JPanel();
  private JTextField outputField;
  private JButton browseButton = new JButton("Browse");
  private JButton okButton = new JButton("OK");
  private JButton cancelButton = new JButton("Cancel");
  private JComboBox<String> formatComboBox = new JComboBox<String>();
  
  
  private Collection<GPVGene> genesToSave;
  final private CanvasProperties properties;
  
  private final JPanel panel = new JPanel();
  private final JPanel panel_1 = new JPanel();
  private final JProgressBar progressBar = new JProgressBar();
  private final Component verticalStrut_1 = Box.createVerticalStrut(11);
  private final Component verticalStrut = Box.createVerticalStrut(7);
  
  private Thread savingThread; 
  private final JPanel panel_2 = new JPanel();
  private final ImageSizePanel imageSizePanel = new ImageSizePanel();
  private final JPanel panel_3 = new JPanel();
  private final JPanel panel_4 = new JPanel();
  private final JLabel errLabel = new JLabel("");
  private JLabel oflabel = new JLabel();
  private final JCheckBox chckbxMultipage = new JCheckBox("Write multipage document");
  private final JLabel lblNewLabel = new JLabel("Mode:");
  
  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    try
    {
      BatchImageSaveDialog dialog = new BatchImageSaveDialog();
      dialog.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
      dialog.setVisible(true);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  /**
   * Create the dialog.
   */
  public BatchImageSaveDialog()
  {
    init();
    this.properties =null;
  }
  
  /**
   * Create the dialog.
   */
  public BatchImageSaveDialog(MainWindow parent)
  {
    super(parent);
    init();
    this.properties =null;
  }
  
  /**
   * Create the dialog.
   */
  public BatchImageSaveDialog(MainWindow parent, Collection<GPVGene> genes, CanvasProperties props)
  {
    super(parent);
    init();
    genesToSave = genes;
    this.properties = props;
  }
  
  /**
   * Create the dialog.
   */
  public BatchImageSaveDialog(MainWindow parent, GPVGene gene, CanvasProperties props)
  {
    super(parent);
    oneFile = true;
    init();
    genesToSave = new ArrayList<GPVGene>();
    genesToSave.add(gene);
    this.properties = props;
  }
  
  private void init() {
    setBounds(100, 100, 587, 359);
    setLocationRelativeTo(this.getParent());
    getContentPane().setLayout(new BorderLayout());
    {
      getContentPane().add(panel_2, BorderLayout.CENTER);
    }
    panel_2.setLayout(new BorderLayout(0, 0));
    {
      FlowLayout flowLayout = (FlowLayout) panel_4.getLayout();
      flowLayout.setAlignment(FlowLayout.LEFT);
      panel_2.add(panel_4, BorderLayout.SOUTH);
    }
    {
      panel_4.add(errLabel);
    }
    {
      FlowLayout flowLayout = (FlowLayout) panel_3.getLayout();
      panel_2.add(panel_3, BorderLayout.CENTER);
    }
    imageSizePanel.setBorder(new EtchedBorder(EtchedBorder.LOWERED, null, null));
    imageSizePanel.setErrorLabel(this.errLabel);
    panel_3.add(imageSizePanel);
    panel_2.add(topPanel, BorderLayout.NORTH);
    topPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
    topPanel.setLayout(new FormLayout(new ColumnSpec[] {
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.DEFAULT_COLSPEC,
        FormFactory.RELATED_GAP_COLSPEC,
        ColumnSpec.decode("default:grow"),
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.DEFAULT_COLSPEC,},
      new RowSpec[] {
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        RowSpec.decode("default:grow"),}));
    {
      lblNewLabel.setHorizontalAlignment(SwingConstants.RIGHT);
      topPanel.add(lblNewLabel, "2, 2");
    }
    {
      oflabel = new JLabel("Output "+(oneFile?"file":"directory")+":");
      topPanel.add(oflabel, "2, 4, right, default");
    }
    {
      outputField = new JTextField(GPViz.getInstance().getOptions().getLastImageSaveDir());
      topPanel.add(outputField, "4, 4, fill, default");
      outputField.setColumns(10);
    }
    {
      
      topPanel.add(browseButton, "6, 4");
      browseButton.addActionListener(this);
    }
    {
      JLabel lblNewLabel_1 = new JLabel("Image format:");
      topPanel.add(lblNewLabel_1, "2, 6, right, default");
    }
    {
      initFileFormats(false);
      formatComboBox.setSelectedItem("png");
      formatComboBox.addItemListener(this);
      topPanel.add(formatComboBox, "4, 6, fill, default");
    }
    {
      chckbxMultipage.setVisible(!oneFile);
      lblNewLabel.setVisible(!oneFile);
      chckbxMultipage.addActionListener(this);
      topPanel.add(chckbxMultipage, "4, 2");
    }
    {
      errLabel.setForeground(Color.RED);
    }
    {
      JPanel buttonPane = new JPanel();
      getContentPane().add(buttonPane, BorderLayout.SOUTH);
      buttonPane.setLayout(new BorderLayout(0, 0));
      {
        {
          buttonPane.add(panel);
        }
        panel.setLayout(new BorderLayout(0, 0));
        {
          panel.add(verticalStrut_1, BorderLayout.NORTH);
        }
        {
          panel.add(progressBar);
        }
        {
          panel.add(verticalStrut, BorderLayout.SOUTH);
        }
        {
          buttonPane.add(panel_1, BorderLayout.EAST);
        }
        panel_1.add(okButton);
        okButton.setActionCommand("OK");
        okButton.addActionListener(this);
        getRootPane().setDefaultButton(okButton);
      }
      {
        panel_1.add(cancelButton);
        cancelButton.addActionListener(this);
        cancelButton.setActionCommand("Cancel");
      }
    }
  }

  private File chooseOutputDir(){
    String lastsavedir = GPViz.getInstance().getOptions().getLastImageSaveDir();
    if(lastsavedir==null)lastsavedir = System.getProperty("user.home");

    JFileChooser chooser = new JFileChooser(lastsavedir);
    chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
    chooser.setFileFilter(new FileFilter()
    {
      @Override
      public String getDescription()
      {
        return "Directory";
      }

      @Override
      public boolean accept(File f)
      {
        return f.isDirectory();
      }
    });
    
    int ret = chooser.showDialog(this, "Save");

    if(ret==JFileChooser.APPROVE_OPTION){
      GPViz.getInstance().getOptions().setLastImageSaveDir(chooser.getSelectedFile().getAbsolutePath());
      GPVOptions.save(GPViz.getInstance().getOptions());
      File chosen = chooser.getSelectedFile();
      return chosen;
    }
    
    return null;
  }

  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource() == this.browseButton){
      File output;
      if(oneFile){
        output = GPVImageWriter.chooseOutputFile(this,oneFile&&genesToSave.size()>1);
      }else{
        output = chooseOutputDir();
      }
      
      if(output != null){
        String outputpath = output.getAbsolutePath();
        String format = FileUtils.getExtension(output.getName());
        if(format==null || format.equals("")){
          if(oneFile){
            format = (String)formatComboBox.getSelectedItem();
            outputpath = FileUtils.replaceFileExtension(outputpath,"."+format);
          }
        }else{
          formatComboBox.setSelectedItem(format);
        }
        
        outputField.setText(outputpath);
      }
    }else if(e.getSource()==cancelButton){
      if(savingThread!=null && savingThread.isAlive()){
        savingThread.interrupt();
      }
      setVisible(false);
    }else if(e.getSource()==okButton){
      if(validateForm()){
        final Dimension size = imageSizePanel.getSizeInPixels();
        final BatchImageSaveDialog me = this;
        final File output = new File(outputField.getText());
        final String format = (String)formatComboBox.getSelectedObjects()[0];
        
        this.okButton.setEnabled(false);
        this.browseButton.setEnabled(false);
        this.outputField.setEnabled(false);
        this.formatComboBox.setEnabled(false);
        this.imageSizePanel.setEnabled(false);
        
        
        GPViz.getInstance().getOptions().setLastImageSaveDir(oneFile?output.getParent():output.getAbsolutePath());
        GPVOptions.save(GPViz.getInstance().getOptions());
        final GPVDataContainer data = GPViz.getInstance().getDataContainer();
        
        savingThread = new Thread(){
          public void run(){
            GPVImageWriter writer = new GPVImageWriter(properties, size, me, me);
            try{
              if(oneFile){
                File fixedoutput = output;
                if(!FileUtils.getExtension(output.getName()).equals(format)){
                  fixedoutput = new File(output.getAbsoluteFile()+"."+format);
                }
                if(genesToSave.size()==1){
                  writer.writeGene(data, fixedoutput, genesToSave.iterator().next());
                  me.set(100);
                  me.close();
                }else{
                  writer.writeGenesToMultipageFile(data, genesToSave, fixedoutput);
                }
              }else{
                writer.writeGenes(data, genesToSave, output, format);
              }
            }
            catch (Exception e)
            {
              JOptionPane.showMessageDialog(me, "Could not write image to " + output + ". Error: " + e.getMessage());
              e.printStackTrace();
            }
          }
        };
        savingThread.start();
        
      }
    }else if(e.getSource() == chckbxMultipage){
      setMultiplePagesToOneFile(chckbxMultipage.isSelected());
    }
  }
  
  private void initFileFormats(boolean onlyWithMultipageSupport){
    if(onlyWithMultipageSupport){
      formatComboBox.setModel(new DefaultComboBoxModel<String>(GPVImageWriter.getValidFileFormatsWithMultipageSupport()));
    }else{
      formatComboBox.setModel(new DefaultComboBoxModel<String>(GPVImageWriter.getValidFileFormats()));
    }
  }
  
  public void setMultiplePagesToOneFile(boolean onefile){
    this.oneFile = onefile;
    oflabel.setText("Output "+(oneFile?"file":"directory")+":");
    String selected_format = (String)formatComboBox.getSelectedItem();
    initFileFormats(onefile);
    if(!onefile)formatComboBox.setSelectedItem(selected_format);
    selected_format = (String)formatComboBox.getSelectedItem();
    
    String path = outputField.getText();
    if(!path.equals("")){
      File curFile = new File(path);
      boolean isdir = (curFile.exists() && curFile.isDirectory()) || path.endsWith(File.separator);
      String newpath = path;
      if(onefile){
        if(isdir){
          //the current path is an output dir
          curFile = new File(curFile, "GPViz_export."+selected_format);
          newpath = curFile.getAbsolutePath();
        }else{
          newpath = FileUtils.replaceFileExtension(path, "."+selected_format);
        }
      }else{
        if(!isdir){
          newpath = curFile.getParentFile().getAbsolutePath();
        }
      }
      outputField.setText(newpath);
    }
  }

  private boolean validateForm()
  {
    if(!oneFile && !new File(outputField.getText()).isDirectory()){
      errLabel.setText("Invalid outputdir. You have to select a directory.");
      return false;
    }else if(oneFile && new File(outputField.getText()).isDirectory()){
      errLabel.setText("Invalid outputfile. You have to select a file.");
      return false;
    }
    return true;
  }


  @Override
  public void close()
  {
    progressBar.setValue(0);
    setVisible(false);
  }

  @Override
  public int getProgressBarUnits()
  {
    return 100;
  }

  @Override
  public String getText()
  {
    return progressBar.getString();
  }

  @Override
  public void set(int arg0)
  {
    progressBar.setValue(arg0);
  }

  @Override
  public void setText(String arg0)
  {
    progressBar.setString(arg0);
  }

  @Override
  public void itemStateChanged(ItemEvent e)
  {
    if(e.getSource() == formatComboBox){
      if(oneFile){
        String curpath = outputField.getText();
        if(!curpath.equals("")){
          String newpath = FileUtils.replaceFileExtension(curpath, "."+(String)formatComboBox.getSelectedItem());
          outputField.setText(newpath);
        }
      }
    }
  }
}
