/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

public class CheckFreeMemoryThread extends Thread
{
  private MainWindow parent;
  
  private static int byte2mb = 1048576;
  
  public CheckFreeMemoryThread(MainWindow parent){
    this.parent = parent;
  }
  
  public void run(){
    while(!Thread.interrupted()){
      long maxmem =  Runtime.getRuntime().maxMemory();
      long usedmem = (Runtime.getRuntime().totalMemory()-Runtime.getRuntime().freeMemory());

      int usedmb = (int) usedmem/byte2mb;
      int maxmb = (int) maxmem/byte2mb;

      int usedpercent = (int) (100f/maxmem*usedmem);
      String text = usedmb+"mb/"+maxmb+"mb ("+usedpercent+"%)";

      parent.setMemoryUsage(usedpercent, text);
      
      try
      {
        Thread.sleep(500);
      }
      catch (InterruptedException e)
      {
        return;
      }
    }
    
  }
  
  public static synchronized long getFreeMemory(){
    return Runtime.getRuntime().maxMemory()-(Runtime.getRuntime().totalMemory()-Runtime.getRuntime().freeMemory());
  }
  
  
}
