/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.JComponent;
import javax.swing.SwingWorker;

public class FocusTrappingCancelListener implements FocusListener, KeyListener, ActionListener
{
  private JComponent focusKeeper;
  private SwingWorker<?,?> interruptable;
  
  public FocusTrappingCancelListener(JComponent focusKeeper){
    this.focusKeeper = focusKeeper;
  }

  @Override
  public void focusGained(FocusEvent e)
  {
  }
  
  public void cancel(){
    if(interruptable!=null){
      this.interruptable.cancel(true);
      this.interruptable = null;
    }
    focusKeeper.setEnabled(false);
  }
  
  public void setWorker(SwingWorker<?,?> worker){
    this.interruptable = worker;
    focusKeeper.setEnabled(worker!=null);
  }
  
  @Override
  public void focusLost(FocusEvent e)
  {
    if(e.getOppositeComponent()!=null)focusKeeper.requestFocus();
  }

  @Override
  public void keyTyped(KeyEvent e)
  {
  }

  @Override
  public void keyPressed(KeyEvent e)
  {
    if(e.getKeyCode()==KeyEvent.VK_ESCAPE){
      cancel();
    }    
  }

  @Override
  public void keyReleased(KeyEvent e)
  {
  }

  @Override
  public void actionPerformed(ActionEvent e)
  {
    cancel();
  }
}
