/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager;

public class FullSizeLayout implements LayoutManager
{

  @Override
  public void addLayoutComponent(String name, Component comp)
  {
    
  }

  @Override
  public void removeLayoutComponent(Component comp)
  {
    
  }

  @Override
  public Dimension preferredLayoutSize(Container parent)
  {
    return minimumLayoutSize(parent);
  }

  @Override
  public Dimension minimumLayoutSize(Container parent)
  {
    int min_height = 0;
    int min_width = 0;
    for(Component comp:parent.getComponents()){
      Dimension pref_size = comp.getPreferredSize();
      if(pref_size!=null){
        min_height= (int)Math.max(min_height, pref_size.getHeight());
        min_width= (int)Math.max(min_width, pref_size.getWidth());
      }
    }
    return new Dimension(min_width,min_height);
  }

  @Override
  public void layoutContainer(Container parent)
  {
    Insets ins = parent.getInsets();
    Dimension parent_size = parent.getSize();
    Dimension full_size = new Dimension(parent_size.width-ins.left-ins.right, parent_size.height-ins.top-ins.bottom);
    
    for(Component comp:parent.getComponents()){
      Dimension pref_size = comp.getPreferredSize();
      Dimension size = full_size;
      if(pref_size.getHeight()>full_size.getHeight() && pref_size.getWidth()>full_size.getWidth()){
        size = pref_size;
      }
      
      comp.setBounds(ins.left, ins.top, size.width, size.height);
      comp.setLocation(ins.left, ins.top);
      
    }
  }

}
