/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.EmptyBorder;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;

public class ImageSizeDialog extends JDialog implements KeyListener
{

  private static final long serialVersionUID = 3962320041670381401L;
  private final JPanel contentPanel = new JPanel();
  private JTextField textWidth;
  private JTextField textHeight;
  
  private int returnVal = 0;
  private JLabel lblErrorWidth;
  private JLabel lblErrorHeight;
  
  private float ratio = 1f;
  private JCheckBox chckbxKeep;

  /**
   * Create the dialog.
   */
  public ImageSizeDialog(int currwidth, int currheight, JFrame owner)
  {
    super(owner);
    initialize(currwidth, currheight);
  }
  
  /**
   * @wbp.parser.constructor
   */
  public ImageSizeDialog(int currwidth, int currheight)
  {
    initialize(currwidth, currheight); 
  }
  
  private void initialize(int currwidth, int currheight){
    
    ratio = (float)currheight/(float)currwidth;
    
    setBounds(100, 100, 378, 179);
    getContentPane().setLayout(new BorderLayout());
    contentPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
    getContentPane().add(contentPanel, BorderLayout.CENTER);
    contentPanel.setLayout(new FormLayout(new ColumnSpec[] {
        FormFactory.RELATED_GAP_COLSPEC,
        ColumnSpec.decode("44px"),
        FormFactory.LABEL_COMPONENT_GAP_COLSPEC,
        ColumnSpec.decode("6px"),
        ColumnSpec.decode("23px"),
        ColumnSpec.decode("131px"),
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.DEFAULT_COLSPEC,},
      new RowSpec[] {
        FormFactory.PARAGRAPH_GAP_ROWSPEC,
        RowSpec.decode("19px"),
        FormFactory.RELATED_GAP_ROWSPEC,
        RowSpec.decode("19px"),
        FormFactory.NARROW_LINE_GAP_ROWSPEC,
        RowSpec.decode("23px"),}));
    
    JLabel lblNewLabel = new JLabel("Width:");
    contentPanel.add(lblNewLabel, "2, 2, 3, 1, fill, center");
    
    textWidth = new JTextField();
    textWidth.addKeyListener(this);
    
    contentPanel.add(textWidth, "6, 2, left, top");
    textWidth.setColumns(10);
    textWidth.setText(""+currwidth);
    
    lblErrorWidth = new JLabel("");
    lblErrorWidth.setForeground(Color.RED);
    contentPanel.add(lblErrorWidth, "8, 2");
    
    JLabel lblNewLabel_1 = new JLabel("Height:");
    contentPanel.add(lblNewLabel_1, "2, 4, 3, 1, left, fill");
    
    textHeight = new JTextField();
    contentPanel.add(textHeight, "6, 4, left, top");
    textHeight.setColumns(10);
    textHeight.setText(""+currheight);
    textHeight.addKeyListener(this);
    
    lblErrorHeight = new JLabel("");
    lblErrorHeight.setForeground(Color.RED);
    contentPanel.add(lblErrorHeight, "8, 4");
    
    chckbxKeep = new JCheckBox("Keep proportion");
    chckbxKeep.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if(chckbxKeep.isSelected()){
          recalculateRatio();
        }
      }
    });
    chckbxKeep.setSelected(true);
    contentPanel.add(chckbxKeep, "4, 6, 3, 1, fill, top");
    {
      JPanel buttonPane = new JPanel();
      buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
      getContentPane().add(buttonPane, BorderLayout.SOUTH);
      {
        final ImageSizeDialog source = this;
        JButton okButton = new JButton("OK");
        okButton.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            source.getLblErrorHeight().setText("");
            source.getLblErrorWidth().setText("");
            boolean valid = validateInput();

            if(valid){
              source.returnVal = JOptionPane.OK_OPTION;
              source.setVisible(false);
            }
          }
        });
        okButton.setActionCommand("OK");
        buttonPane.add(okButton);
        getRootPane().setDefaultButton(okButton);
        
        JButton cancelButton = new JButton("Cancel");
        cancelButton.setActionCommand("Cancel");
        buttonPane.add(cancelButton);
        cancelButton.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            source.returnVal = JOptionPane.CANCEL_OPTION;
            source.getLblErrorHeight().setText("");
            source.getLblErrorWidth().setText("");
            source.setVisible(false);
          }
        });        
      }
    }
  }
  
  private boolean validateInput(){
    try{
      Integer.parseInt(textHeight.getText());
      lblErrorHeight.setText("");
    }catch(NumberFormatException nfe){
      lblErrorHeight.setText("Invalid Number");
      return false;
    }
    
    try{
      Integer.parseInt(textWidth.getText());
      lblErrorWidth.setText("");
    }catch(NumberFormatException nfe){
      lblErrorWidth.setText("Invalid Number");
      return false;
    }
    return true;
  }

  public JTextField getTextWidth()
  {
    return textWidth;
  }

  public JTextField getTextHeight()
  {
    return textHeight;
  }

  public int getReturnVal()
  {
    return returnVal;
  }

  public void setReturnVal(int returnVal)
  {
    this.returnVal = returnVal;
  }
  protected JLabel getLblErrorWidth() {
    return lblErrorWidth;
  }
  protected JLabel getLblErrorHeight() {
    return lblErrorHeight;
  }
  
  protected void recalculateRatio(){
    if(validateInput()){
      int height = Integer.parseInt(textHeight.getText());
      int width = Integer.parseInt(textWidth.getText());
      ratio = (float)height/(float)width;
    }
  }

  @Override
  public void keyTyped(KeyEvent e)
  {

    
  }

  @Override
  public void keyPressed(KeyEvent e)
  {
  }

  @Override
  public void keyReleased(KeyEvent e)
  {
    if(!chckbxKeep.isSelected())return;
    //apply ratio
    if(validateInput()){
      if(e.getSource() == textHeight){
        int height = Integer.parseInt(textHeight.getText());
        int width = (int)(height/ratio);
        textWidth.setText(width+"");
      }
      if(e.getSource() == textWidth){
        int width = Integer.parseInt(textWidth.getText());
        int height = (int)(width*ratio);
        textHeight.setText(height+"");
      }
    }
  }
}
