/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextPane;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

public class LowMemoryDialog extends JDialog
{

  private static final long serialVersionUID = -6677908203260885364L;

  private final JPanel contentPanel = new JPanel();
  
  boolean choice = false;
  
  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    try
    {
      LowMemoryDialog dialog = new LowMemoryDialog();
      dialog.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
      dialog.setVisible(true);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  /**
   * Create the dialog.
   */
  public LowMemoryDialog()
  {
    setTitle("Memory low");
    setBounds(100, 100, 450, 300);
    this.setLocationRelativeTo(null);
    getContentPane().setLayout(new BorderLayout());
    contentPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
    getContentPane().add(contentPanel, BorderLayout.CENTER);
    SpringLayout sl_contentPanel = new SpringLayout();
    contentPanel.setLayout(sl_contentPanel);
    
    JLabel lblNewLabel = new JLabel("Warning: You are running low on memory");
    lblNewLabel.setIcon(new ImageIcon(LowMemoryDialog.class.getResource("/javax/swing/plaf/metal/icons/Warn.gif")));
    sl_contentPanel.putConstraint(SpringLayout.NORTH, lblNewLabel, 10, SpringLayout.NORTH, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.WEST, lblNewLabel, 10, SpringLayout.WEST, contentPanel);
    contentPanel.add(lblNewLabel);
    
    JTextPane txtpnTheSystemIs = new JTextPane();
    txtpnTheSystemIs.setEditable(false);
    sl_contentPanel.putConstraint(SpringLayout.NORTH, txtpnTheSystemIs, -162, SpringLayout.SOUTH, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.WEST, txtpnTheSystemIs, 0, SpringLayout.WEST, lblNewLabel);
    sl_contentPanel.putConstraint(SpringLayout.SOUTH, txtpnTheSystemIs, -10, SpringLayout.SOUTH, contentPanel);
    sl_contentPanel.putConstraint(SpringLayout.EAST, txtpnTheSystemIs, -10, SpringLayout.EAST, contentPanel);
    txtpnTheSystemIs.setBackground(getContentPane().getBackground());
    
    txtpnTheSystemIs.setText("GPViz has detected that Java is running low on memory.\n\nYou can choose to ignore this message, but it might lead to unexpected behavior or loss of data.\n\nPlease consult the manual on how to increase the available memory. You can also visit our homepage for more information:\n\nhttp://icbi.i-med.ac.at/gpviz");
    contentPanel.add(txtpnTheSystemIs);
    {
      JPanel buttonPane = new JPanel();
      buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
      getContentPane().add(buttonPane, BorderLayout.SOUTH);
      {
        JButton ignoreButton = new JButton("Ignore");
        ignoreButton.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            choice = false;
            setVisible(false);
          }
        });
        buttonPane.add(ignoreButton);
        getRootPane().setDefaultButton(ignoreButton);
      }
      {
        JButton cancelButton = new JButton("Abort current operation");
        buttonPane.add(cancelButton);
        cancelButton.addActionListener(new ActionListener()
        {
          @Override
          public void actionPerformed(ActionEvent e)
          {
            choice = true;
            setVisible(false);
          }
        });
      }
    }
    this.setModal(true);
  }
  
  /**
   * @return true if cancel, false if ignore
   */
  public boolean activate(){
    this.setVisible(true);
    return choice;
  }

}
