/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing;

import java.awt.Image;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

public class TransferableImage implements Transferable {

  private Image i;

  public TransferableImage( Image i ) {
    this.i = i;
  }

  public Object getTransferData( DataFlavor flavor )
      throws UnsupportedFlavorException, IOException {
    if ( flavor.equals( DataFlavor.imageFlavor ) && i != null ) {
      return i;
    }
    else {
      throw new UnsupportedFlavorException( flavor );
    }
  }

  public DataFlavor[] getTransferDataFlavors() {
    DataFlavor[] flavors = new DataFlavor[ 1 ];
    flavors[ 0 ] = DataFlavor.imageFlavor;
    return flavors;
  }

  public boolean isDataFlavorSupported( DataFlavor flavor ) {
    DataFlavor[] flavors = getTransferDataFlavors();
    for ( int i = 0; i < flavors.length; i++ ) {
      if ( flavor.equals( flavors[ i ] ) ) {
        return true;
      }
    }

    return false;
  }
}