/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.canvas;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.JMenu;

public class CanvasPropertiesMenu extends JMenu implements ActionListener, CanvasPropertiesChangedListener
{
  private static final long serialVersionUID = -51259476059826384L;
  //canvas settings
  private JCheckBoxMenuItem displayLegend = new JCheckBoxMenuItem("Display legend");
  private JCheckBoxMenuItem displayHighlightings = new JCheckBoxMenuItem("Display region/SNP highlighting");
  private JCheckBoxMenuItem displayExonsToScale = new JCheckBoxMenuItem("Display exons to scale");
  private JCheckBoxMenuItem displayTrackLabels = new JCheckBoxMenuItem("Display labels");
  private JCheckBoxMenuItem displayProteinAxis = new JCheckBoxMenuItem("Display protein axis");
  private JCheckBoxMenuItem displayStartStopCodonLines = new JCheckBoxMenuItem("Display start stop codon lines");
  private JCheckBoxMenuItem displayHelperLines = new JCheckBoxMenuItem("Display helper lines");

  private GPVCanvas canvas;
  
  public CanvasPropertiesMenu(GPVCanvas canvas){
    super("View");
    
    this.canvas = canvas;
    
    displayLegend.addActionListener(this);
    displayHighlightings.addActionListener(this);
    displayExonsToScale.addActionListener(this);
    displayTrackLabels.addActionListener(this);
    displayProteinAxis.addActionListener(this);
    displayHelperLines.addActionListener(this);
    displayStartStopCodonLines.addActionListener(this);
    
    add(displayLegend);
    add(displayHighlightings);
    add(displayExonsToScale);
    add(displayTrackLabels);
    add(displayProteinAxis);
    add(displayStartStopCodonLines);
    add(displayHelperLines);
    
    canvasPropertiesChanged();
  }


  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource() == displayLegend){
      canvas.properties.setDrawAnyLegend(displayLegend.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayHighlightings){
      canvas.properties.setDrawHighlighting(displayHighlightings.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayExonsToScale){
      canvas.properties.setExonsToScale(displayExonsToScale.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayTrackLabels){
      canvas.properties.setDrawGeneAndTranscriptLabels(displayTrackLabels.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayProteinAxis){
      canvas.properties.setShowProteinXAxis(displayProteinAxis.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayHelperLines){
      canvas.properties.setDrawHelperLines(displayHelperLines.isSelected());
      canvas.refresh();
    }else if(e.getSource() == displayStartStopCodonLines){
      canvas.properties.setDrawStartStopCodonLines(displayStartStopCodonLines.isSelected());
      canvas.refresh();
    }
    
    
  }
  
  
  @Override
  public void canvasPropertiesChanged()
  {
    CanvasProperties props = canvas.getProperties();
    displayLegend.setSelected(props.isDrawDomainRegionLegend());
    displayHighlightings.setSelected(props.isDrawHighlighting());
    displayExonsToScale.setSelected(canvas.getProperties().isExonsSetToScale());
    displayTrackLabels.setSelected(props.isDrawGeneAndTranscriptLabels());
    displayProteinAxis.setSelected(props.isShowProteinXAxis());
    displayHelperLines.setSelected(props.isDrawHelperLines());
    displayStartStopCodonLines.setSelected(props.isDrawStartStopCodonLines());    
  }
}
