/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.detailpane;

import java.awt.Component;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.JTable;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.util.TableWriter;

public class DetailsTablePanel extends JTabbedPane implements ChangeListener, ActionListener, TableContainer
{
  private static final long serialVersionUID = -4178559239802545047L;

  private HighlightedRegionTablePanel highlightedRegionTable;
  private VariantsTablePanel variantsTable;
  private GeneDetailsPanel geneDetails;
  private ProteinDomainsTablePanel proteinDomainsTable;

  private JButton saveButton;

  public DetailsTablePanel(){
    super(JTabbedPane.TOP);

    geneDetails = new GeneDetailsPanel();
    this.addTab("Gene & Transcripts", null, geneDetails, null);
    highlightedRegionTable = new HighlightedRegionTablePanel();
    this.addTab("Highlighted regions", null, highlightedRegionTable, null);
    this.addChangeListener(this);

    variantsTable = new VariantsTablePanel();
    this.addTab("Variants", null, variantsTable, null);

    proteinDomainsTable = new ProteinDomainsTablePanel();
    this.addTab("Protein domains", null, proteinDomainsTable, null);


    saveButton = new JButton();
    saveButton.setIcon(new ImageIcon(DetailsTablePanel.class.getResource("/com/sun/java/swing/plaf/windows/icons/FloppyDrive.gif")));
    saveButton.setOpaque(false);
    saveButton.setBorder(new EmptyBorder(2,0,0,0));
    saveButton.addActionListener(this);

    refreshSaveIcon();
  }
  public void refreshEverything(GPVGene gene){
    highlightedRegionTable.refreshHighlightedRegionTable(gene);
    geneDetails.refreshGeneDetails(gene);
    proteinDomainsTable.refreshProteinDomainsTable(gene);
    variantsTable.refreshVariantTable(gene);
    refreshSaveIcon();
  }

  @Override
  public void stateChanged(ChangeEvent e)
  {
    if(e.getSource()==this){
      refreshSaveIcon();
    }
  }

  private void refreshSaveIcon(){
    int selected = this.getSelectedIndex();
    JTable table = getTable();
    if(table!=null){

      String text = getTitleAt(selected);

      JPanel test = new JPanel();
      test.setOpaque(false);
      test.setLayout(new FlowLayout(FlowLayout.CENTER,0,0));
      JLabel header = new JLabel(text);
      header.setBorder(new EmptyBorder(1,0,0,0));
      test.add(header);

      test.add(Box.createHorizontalStrut(5));
      test.add(saveButton);
      saveButton.setEnabled(table.getRowCount()>0);

      this.setTabComponentAt(selected, test);

    }

    for(int i = 0; i<getTabCount(); i++){
      if(i!=selected) this.setTabComponentAt(i, null);
    }
  }

  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource() == saveButton){
      JTable table = getTable();
      if(table!=null){
        new TableWriter().writeTable(table);
      }
    }
  }

  public JTable getTable(){
    Component selected = this.getSelectedComponent();
    if(selected instanceof TableContainer){
      return ((TableContainer)selected).getTable();
    }
    return null;
  }

}
