/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.detailpane;

import java.awt.BorderLayout;
import java.awt.Font;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTable;

import at.icbi.gpviz.data.GPVGene;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;

public class GeneDetailsPanel extends JPanel implements TableContainer
{
  private static final long serialVersionUID = -4445947245863185955L;

  private TranscriptDetailsTablePanel transcriptsTable; 
  
  private JLabel lblGeneID = new JLabel("");
  private JLabel lblUniGeneID = new JLabel("");
  private JLabel lblGeneSymbol = new JLabel("");
  private JLabel lblGeneName = new JLabel("");
  private JLabel lblRange = new JLabel("");
  
  public GeneDetailsPanel(){
    this.setLayout(new BorderLayout());
    
    JPanel panel = new JPanel();
    add(panel, BorderLayout.NORTH);
    panel.setLayout(new FormLayout(new ColumnSpec[] {
        FormFactory.UNRELATED_GAP_COLSPEC,
        ColumnSpec.decode("left:pref"),
        ColumnSpec.decode("2dlu"),
        ColumnSpec.decode("max(200px;pref)"),
        FormFactory.UNRELATED_GAP_COLSPEC,
        FormFactory.PREF_COLSPEC,
        ColumnSpec.decode("2dlu"),
        FormFactory.PREF_COLSPEC,},
      new RowSpec[] {
        FormFactory.LINE_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.LINE_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.LINE_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.LINE_GAP_ROWSPEC,}));
    
    JLabel lblNewLabel_4 = new JLabel("Range:");
    lblNewLabel_4.setFont(new Font("Dialog", Font.BOLD, 12));
    panel.add(lblNewLabel_4, "2, 2");
    
    
    panel.add(lblRange, "4, 2, 3, 1");
    
    JLabel lblNewLabel = new JLabel("Gene ID:");
    lblNewLabel.setFont(new Font("Dialog", Font.BOLD, 12));
    panel.add(lblNewLabel, "2, 4, left, top");
    
    panel.add(lblGeneID, "4, 4");
    
    JLabel lblNewLabel_3 = new JLabel("Unigene ID:");
    lblNewLabel_3.setFont(new Font("Dialog", Font.BOLD, 12));
    panel.add(lblNewLabel_3, "6, 4");

    panel.add(lblUniGeneID, "8, 4");
    
    JLabel lblNewLabel_1 = new JLabel("Gene symbol:");
    lblNewLabel_1.setFont(new Font("Dialog", Font.BOLD, 12));
    panel.add(lblNewLabel_1, "2, 6");

    
    panel.add(lblGeneSymbol, "4, 6");
    
    JLabel lblNewLabel_2 = new JLabel("Gene name:");
    lblNewLabel_2.setFont(new Font("Dialog", Font.BOLD, 12));
    panel.add(lblNewLabel_2, "6, 6");
    
    panel.add(lblGeneName, "8, 6");
    transcriptsTable = new TranscriptDetailsTablePanel();
    this.add(transcriptsTable, BorderLayout.CENTER);
  }
  
  public void refreshGeneDetails(GPVGene gene){
    if(gene==null){
      lblGeneID.setText("");
      lblGeneSymbol.setText("");
      lblGeneName.setText("");
      lblGeneID.setText("");
      lblRange.setText("");
    }else{
      lblGeneID.setText(gene.getGeneID());
      lblGeneSymbol.setText(gene.getGeneSymbol());
      lblGeneName.setText(gene.getGeneFullName());
      lblGeneID.setText(gene.getGeneID());
      lblRange.setText(gene.getChromosome().getName()+":"+gene.getFirstKnownPosition()+"-"+gene.getLastKnownPosition());
    }
    
    transcriptsTable.refreshTranscriptTable(gene);
  }

  @Override
  public JTable getTable()
  {
    return transcriptsTable.getTable();
  }
}
