/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.detailpane;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map.Entry;

import javax.swing.table.DefaultTableModel;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVDomain;
import at.icbi.gpviz.data.GPVGene;

public class ProteinDomainsTablePanel extends SimpleTablePanel
{
  private static final long serialVersionUID = 7335962620751980363L;

  private static final String[] baseheaders = new String[] { "Category", "Protein","Domain ID", "Description", "Start", "Stop" };

  public void refreshProteinDomainsTable(GPVGene selectedGene)
  {
    DefaultTableModel model;
    GPVDataContainer data = GPViz.getInstance().getDataContainer();
    if (selectedGene != null)
    {
      String[] additional_columns =  data.getAdditionalDomainSetInfoKeys().toArray(new String[0]);

      String[] headers = new String[baseheaders.length+additional_columns.length];
      for(int i = 0; i < baseheaders.length; i++) headers[i] = baseheaders[i];
      for(int i = 0; i < additional_columns.length; i++) headers[baseheaders.length+i] = additional_columns[i];
      
      HashMap<String,ArrayList<GPVDomain>> all_domains = data.getProteinDomainsForGene(selectedGene, true);
      int num_domains = 0;
      for(Entry<String,ArrayList<GPVDomain>> set:all_domains.entrySet()){
        num_domains+=set.getValue().size();
      }

      model = new DefaultTableModel(headers, num_domains);
      int row = 0;
      for(Entry<String,ArrayList<GPVDomain>> set:all_domains.entrySet()){
        for(GPVDomain domain:set.getValue()){
          int col = 0;
          model.setValueAt(domain.getParentSet().getSetName(), row, col++);
          model.setValueAt(domain.getProteinId(), row, col++);
          model.setValueAt(domain.getDomainId(), row, col++);
          model.setValueAt(domain.getDescription(), row, col++);
          model.setValueAt(domain.getProteinStartPos(), row, col++);
          model.setValueAt(domain.getProteinEndPos(), row, col++);
          for(String key:additional_columns){
            model.setValueAt(domain.getAdditionalData().get(key), row, col++);
          }
          row++;
        }
      }
    } else
    {
      model = new DefaultTableModel(baseheaders, 0);
    }
    table.setModel(model);
    table.repaint();
  }
}
