/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.detailpane;

import javax.swing.table.DefaultTableModel;

import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVTranscript;

public class TranscriptDetailsTablePanel extends SimpleTablePanel
{
  private static final long serialVersionUID = 7335962620751980363L;

  private static final String[] headers = new String[]{"Transcript ID", "Start codon", "Stop codon", "Protein ID", "Uniprot ID","Protein length"};
//  private static final int[] colwidths = new int[]{85,85,85,400,85,85,85,85};
  
  public void refreshTranscriptTable(GPVGene selectedGene){
    DefaultTableModel model;
    
    if(selectedGene!=null){
      model = new DefaultTableModel(headers,selectedGene.getTranscripts().size());
      //filling the table top to bottom as a cheap way to reverse the sorting
      //In the figure I want coding transcripts at the bottom - that's why they are sorted that way,
      //but in the table I want coding transcripts at the top so i can see them better.
      int row = model.getRowCount()-1;
      for(GPVTranscript transcript: selectedGene.getSortedTranscripts()) {
        model.setValueAt(transcript.getTranscriptId(), row, 0);
        if(transcript.isCoding()){
          model.setValueAt(transcript.getStartCodon(), row, 1);
          model.setValueAt(transcript.getStopCodon(), row, 2);
          model.setValueAt(transcript.getResultingProtein().getProteinID(), row, 3);
          model.setValueAt(transcript.getResultingProtein().getProteinUniprotId(), row, 4);
          model.setValueAt(transcript.getResultingProtein().getProteinLength(), row, 5);
        }
        
        row--;
      }
    }else{
      model = new DefaultTableModel(headers,0);
    }
    table.setModel(model);
//    for(int i = 0; i < colwidths.length; i++){
//      table.getColumnModel().getColumn(i).setPreferredWidth(colwidths[i]);
//    }

    table.repaint();
  }
}
