/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.detailpane;

import java.util.Collection;

import javax.swing.table.DefaultTableModel;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.regions.GPVHighlightedRegion;
import at.icbi.gpviz.data.regions.GPVVariant;

public class VariantsTablePanel extends SimpleTablePanel
{
  private static final long serialVersionUID = 7335962620751980363L;

  private static final String[] headers = new String[] { "Chromosome", "Position", "Classification", "dbSNP ID" };
  private static final int[] colwidths = new int[]{10,20,35,35};

  public void refreshVariantTable(GPVGene selectedGene)
  {
    // refresh highlighted region table
    DefaultTableModel model;
    GPVDataContainer data = GPViz.getInstance().getDataContainer();
    if (selectedGene != null)
    {
      Collection<GPVHighlightedRegion> regions = data.getHighlightedRegionsForGene(selectedGene,true,false,true);
      
      model = new DefaultTableModel(headers, regions.size());
      int row = 0;
      for (GPVHighlightedRegion region:regions)
      {
        if(region instanceof GPVVariant){
          GPVVariant variant = (GPVVariant) region;
          model.setValueAt(variant.getChromosome().getTrimmedName(), row, 0);
          model.setValueAt(variant.getStart(), row, 1);
          model.setValueAt(variant.getVariantTypeString(false),row,2);
          model.setValueAt(variant.getDbSNPID(), row, 3);
          row++;
        }
      }
    } else
    {
      model = new DefaultTableModel(headers, 0);
    }

    table.setModel(model);
    for(int i = 0; i < colwidths.length; i++){
      table.getColumnModel().getColumn(i).setPreferredWidth(colwidths[i]);
    }
    
    table.repaint();
  }
}
