/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.options;

import java.awt.Color;
import java.awt.EventQueue;

import javax.swing.JLabel;
import javax.swing.JPanel;

import at.icbi.gpviz.data.GPVOptions;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;
import javax.swing.JCheckBox;

public class AdvancedOptionsPanel extends JPanel implements ProgramOptionTab
{
  private static final long serialVersionUID = -2085916476046917866L;
  private JLabel errorLabel = new JLabel("");
  private final JCheckBox chckbxNewCheckBox = new JCheckBox("Use protein domain caching");

  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    EventQueue.invokeLater(new Runnable()
    {
      public void run()
      {
        try
        {
          AdvancedOptionsPanel frame = new AdvancedOptionsPanel();
          frame.setVisible(true);
        }
        catch (Exception e)
        {
          e.printStackTrace();
        }
      }
    });
  }

  
  /**
   * Create the frame.
   */
  public AdvancedOptionsPanel()
  {
    super();
    init();
  }
  
  private void init(){
    
    setBounds(0, 0, 500, 600);
    
    this.setLayout(new FormLayout(new ColumnSpec[] {
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.DEFAULT_COLSPEC,
        FormFactory.RELATED_GAP_COLSPEC,
        ColumnSpec.decode("default:grow"),
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.BUTTON_COLSPEC,
        FormFactory.RELATED_GAP_COLSPEC,},
      new RowSpec[] {
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,}));
    
    JLabel lblNewLabel = new JLabel("The following options require you to restart GPViz to take effect:");
    add(lblNewLabel, "2, 2");
    chckbxNewCheckBox.setToolTipText("This option greatly increases the performance at which images are drawn, but requires some additional memory. If you are low on memory you can disable this function.");
    
    add(chckbxNewCheckBox, "2, 4");
    
    errorLabel.setForeground(Color.red);
    this.add(errorLabel, "4, 24");
    
  }
  
  @Override
  public boolean validateOptions(){
    return true;
  }


  @Override
  public void fillWithOptions(GPVOptions source)
  {
    if(source!=null){
      chckbxNewCheckBox.setSelected(source.isUseProteinDomainCache());
    }
  }

  @Override
  public void save(GPVOptions target)
  {
    target.setUseProteinDomainCache(chckbxNewCheckBox.isSelected());
  }


  @Override
  public String getTitle()
  {
    return "Advanced";
  }

}
