/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.options;

import java.awt.Color;
import java.awt.EventQueue;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.weblinks.WebLink;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;

public class DataSourcesPanel extends JPanel implements ActionListener, ProgramOptionTab
{
  private static final long serialVersionUID = -2085916476046917866L;
  
  private JTextField txtRefseqAnnotationFile;
  private JTextField txtEnsemblAnnotationFile;
  private JButton btnBrowseRefseqAnnotationFile = new JButton("Browse...");
  private JButton btnBrowseEnsemblAnnotationFile = new JButton("Browse...");
  private JLabel errorLabel = new JLabel("");
  private final JLabel lblGeneLink = new JLabel("Gene link");
  private final JLabel lblTranscriptLink = new JLabel("Transcript link");
  private final JLabel lblProteinLink = new JLabel("Protein link");
  private final JLabel lblGenomeBrowserLink = new JLabel("Genome Browser:");
  private final JTextField textGeneLink = new JTextField();
  private final JTextField textTranscriptLink = new JTextField();
  private final JTextField textProteinLink = new JTextField();
  private final JTextField textGenomeBrowserLink = new JTextField();
  private final JLabel lblNewLabel = new JLabel("Web links:");

  /**
   * Launch the application.
   */
  public static void main(String[] args)
  {
    EventQueue.invokeLater(new Runnable()
    {
      public void run()
      {
        try
        {
          DataSourcesPanel frame = new DataSourcesPanel();
          frame.setVisible(true);
        }
        catch (Exception e)
        {
          e.printStackTrace();
        }
      }
    });
  }

  
  /**
   * Create the frame.
   */
  public DataSourcesPanel()
  {
    super();
    init();
  }
  
  private void init(){
    
    setBounds(0, 0, 500, 600);
    
    this.setLayout(new FormLayout(new ColumnSpec[] {
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.DEFAULT_COLSPEC,
        FormFactory.RELATED_GAP_COLSPEC,
        ColumnSpec.decode("default:grow"),
        FormFactory.RELATED_GAP_COLSPEC,
        FormFactory.BUTTON_COLSPEC,
        FormFactory.RELATED_GAP_COLSPEC,},
      new RowSpec[] {
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,
        FormFactory.RELATED_GAP_ROWSPEC,
        FormFactory.DEFAULT_ROWSPEC,}));
    
    JLabel refseqUniprotFileLabel = new JLabel("Refseq Annotation File");
    this.add(refseqUniprotFileLabel, "2, 2, left, default");
    
    txtRefseqAnnotationFile = new JTextField();
    this.add(txtRefseqAnnotationFile, "4, 2, fill, default");
    txtRefseqAnnotationFile.setColumns(10);
    
    btnBrowseRefseqAnnotationFile.addActionListener(this);
    this.add(btnBrowseRefseqAnnotationFile, "6, 2");
    
    JLabel ensemblUniprotFileLabel = new JLabel("Ensembl Annotation File");
    this.add(ensemblUniprotFileLabel, "2, 4, left, default");
    
    txtEnsemblAnnotationFile = new JTextField();
    this.add(txtEnsemblAnnotationFile, "4, 4, fill, default");
    txtEnsemblAnnotationFile.setColumns(10);
    
    btnBrowseEnsemblAnnotationFile.addActionListener(this);
    this.add(btnBrowseEnsemblAnnotationFile, "6, 4");
    
    add(lblNewLabel, "2, 8");
    
    add(lblGeneLink, "2, 10, left, default");
    
    add(textGeneLink, "4, 10, 3, 1, fill, default");
    textGeneLink.setToolTipText("<html><p>The path to the website opened when clicking the gene name.<br><br>You can use the following variables:<br>"+createVariableList(WebLink.getVariablesForGeneLink())+"</p></html>");
    textGeneLink.setColumns(10);
    
    add(lblTranscriptLink, "2, 12, left, default");
    
    add(textTranscriptLink, "4, 12, 3, 1, fill, default");
    textTranscriptLink.setToolTipText("<html><p>The path to the website opened when clicking the transcript name.<br><br>You can use the following variables:<br>"+createVariableList(WebLink.getVariablesForTranscriptLink())+"</p></html>");
    textTranscriptLink.setColumns(10);
    
    add(lblProteinLink, "2, 14, left, default");
    
    add(textProteinLink, "4, 14, 3, 1, fill, default");
    
    textProteinLink.setToolTipText("<html><p>The path to the website opened when clicking the protein name.<br><br>You can use the following variables:<br>"+createVariableList(WebLink.getVariablesForProteinLink())+"</p></html>");
    textProteinLink.setColumns(10);
    
    
    add(lblGenomeBrowserLink, "2, 16, left, default");
    add(textGenomeBrowserLink, "4, 16, 3, 1, fill, default");
    
    textGenomeBrowserLink.setToolTipText("<html><p>The path to the website opened when clicking on a highlighted genomic region.<br><br>You can use the following variables:<br>"+createVariableList(WebLink.getVariablesForRegionLink())+"</p></html>");
    textGenomeBrowserLink.setColumns(10);
    
    errorLabel.setForeground(Color.red);
    this.add(errorLabel, "4, 24");
    
  }
  
  private String createVariableList(String[] variables){
    String ret = "";
    for(int i = 0; i < variables.length; i++){
      if(i>0){
        ret+=", ";
      }
      ret+=WebLink.decorateVariable(variables[i]);
    }
    return ret;
  }
  
  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource() == btnBrowseRefseqAnnotationFile || e.getSource() == btnBrowseEnsemblAnnotationFile){
      String lastsavedir = GPViz.getInstance().getOptions().getLastInputDir();
      if(lastsavedir==null)lastsavedir = System.getProperty("user.home");
      
      JFileChooser chooser = new JFileChooser(lastsavedir);
      chooser.showOpenDialog(this);
      if(chooser.getSelectedFile()!=null){
        try
        {
          if(e.getSource() == btnBrowseEnsemblAnnotationFile){
            txtEnsemblAnnotationFile.setText(chooser.getSelectedFile().getCanonicalPath());
          }else{
            txtRefseqAnnotationFile.setText(chooser.getSelectedFile().getCanonicalPath());
          }
        }
        catch (IOException e1)
        {
          e1.printStackTrace();
        }
      }
    }
  }
  
  @Override
  public boolean validateOptions(){
    if(txtRefseqAnnotationFile.getText()!= null && !txtRefseqAnnotationFile.getText().trim().equals("")){
      if(!new File(txtRefseqAnnotationFile.getText()).canRead()){
        errorLabel.setText("Invalid Refseq Annotation File.");
        return false;
      }
    }
    if(txtEnsemblAnnotationFile.getText()!= null && !txtEnsemblAnnotationFile.getText().trim().equals("")){
      if(!new File(txtEnsemblAnnotationFile.getText()).canRead()){
        errorLabel.setText("Invalid Ensembl Annotation File.");
        return false;
      }
    }
    errorLabel.setText("");
    return true;
  }


  @Override
  public void fillWithOptions(GPVOptions source)
  {
    if(source!=null){
      this.txtRefseqAnnotationFile.setText(source.getNMtoNPFile());
      this.txtEnsemblAnnotationFile.setText(source.getEnsemblToUniprotFile());
      this.textGeneLink.setText(source.getGeneInfoLinkBase());
      this.textProteinLink.setText(source.getProteinInfoLinkBase());
      this.textGenomeBrowserLink.setText(source.getRegionLinkBase());
      this.textTranscriptLink.setText(source.getTranscriptInfoLinkBase());
    }
  }

  @Override
  public void save(GPVOptions target)
  {
    target.setNMtoNPFile(txtRefseqAnnotationFile.getText());
    target.setEnsemblToUniprotFile(txtEnsemblAnnotationFile.getText());
    target.setGeneInfoLinkBase(textGeneLink.getText());
    target.setProteinInfoLinkBase(textProteinLink.getText());
    target.setRegionLinkBase(textGenomeBrowserLink.getText());
    
    target.setTranscriptInfoLinkBase(textTranscriptLink.getText());
  }


  @Override
  public String getTitle()
  {
    return "Annotations";
  }

}
