/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.options;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVOptions;
import at.icbi.gpviz.swing.MainWindow;

public class ProgramOptionsDialog extends JDialog implements ActionListener
{

  private static final long serialVersionUID = 3713831431888707603L;
  private final JPanel contentPanel = new JPanel();
  private JTabbedPane tabbedPane = new JTabbedPane(JTabbedPane.TOP);
  private JButton okButton = new JButton("OK");
  private JButton cancelButton = new JButton("Cancel");

  /**
   * Create the dialog.
   */
  public ProgramOptionsDialog(MainWindow parent)
  { 
    super(parent);
    init();
  }
  
  
  private void init(){
    setModal(true);
    setBounds(0, 0, 500, 630);
    setLocationRelativeTo(getParent());
    getContentPane().setLayout(new BorderLayout());
    getContentPane().add(contentPanel, BorderLayout.CENTER);
    contentPanel.setLayout(new BorderLayout(0, 0));
    contentPanel.add(tabbedPane, BorderLayout.CENTER);
    JPanel buttonPane = new JPanel();
    buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
    getContentPane().add(buttonPane, BorderLayout.SOUTH);
    okButton.addActionListener(this);
    buttonPane.add(okButton);
    getRootPane().setDefaultButton(okButton);
    cancelButton.addActionListener(this);
    buttonPane.add(cancelButton);


    ColorSchemePanel colorschemes = new ColorSchemePanel(this);
    tabbedPane.addTab(colorschemes.getTitle(), colorschemes);
    DataSourcesPanel datasources = new DataSourcesPanel();
    tabbedPane.addTab(datasources.getTitle(), datasources);
    AdvancedOptionsPanel advanced = new AdvancedOptionsPanel();
    tabbedPane.addTab(advanced.getTitle(), advanced);
    
    
    GPVOptions opts = GPViz.getInstance().getOptions();
    for(int i = 0; i < tabbedPane.getTabCount();i++){
      Component tab_component = tabbedPane.getComponentAt(i);
      if(tab_component instanceof ProgramOptionTab){
        ProgramOptionTab tab = (ProgramOptionTab) tab_component;
        tab.fillWithOptions(opts);
      }else{
        System.err.println("There is a tab in the Option Dialog that doesn't implement the right interface.");
      }
    }
  }

  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource()==okButton){
      boolean valid = true;
      for(int i = 0; i < tabbedPane.getTabCount() && valid;i++){
        Component tab_component = tabbedPane.getComponentAt(i);
        if(tab_component instanceof ProgramOptionTab){
          ProgramOptionTab tab = (ProgramOptionTab) tab_component;
          if(!tab.validateOptions()){
            valid = false;
            tabbedPane.setSelectedIndex(i);
          }
        }
      }
      if(valid){
        GPVOptions opts = GPViz.getInstance().getOptions();
        for(int i = 0; i < tabbedPane.getTabCount() && valid;i++){
          Component tab_component = tabbedPane.getComponentAt(i);
          if(tab_component instanceof ProgramOptionTab){
            ProgramOptionTab tab = (ProgramOptionTab) tab_component;
            tab.save(opts);
          }
        }
        GPVOptions.save(opts);
        if(getParent() instanceof MainWindow){
          ((MainWindow)getParent()).refreshEverything();
        }
        
        this.setVisible(false);
      }
    }else if(e.getSource()==cancelButton){
      this.setVisible(false);
    }
  }

}
