/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.sidebar;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Box;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.border.EmptyBorder;

import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.swing.MainWindow;
import at.icbi.gpviz.swing.VerticalFlowLayout;
import at.icbi.gpviz.swing.canvas.CanvasProperties;

public class DisplayPropertiesPanel extends JPanel implements ActionListener
{
  private static final long serialVersionUID = 7318486179017048829L;

  private JRadioButton rdbtnHighlightModeAll = new JRadioButton("All");
  private JRadioButton rdbtnHighlightModeDomain = new JRadioButton("Overlaps only");
  
  private TranscriptChooserPanel transcriptChooserPanel;
  
  private DomainSetChooserPanel domainSetChooserPanel;
  
  private RegionSetChooserPanel regionSetChooserPanel;
 
  private MainWindow parent;
  
  public static ImageIcon COLLAPSE_ICON = new ImageIcon(MainWindow.class.getResource("/at/icbi/gpviz/icons/kamiyamane/application-sidebar-collapse2.png"));
  public static ImageIcon EXPAND_ICON = new ImageIcon(MainWindow.class.getResource("/at/icbi/gpviz/icons/kamiyamane/application-sidebar-expand2.png"));
  
  public DisplayPropertiesPanel(MainWindow parent){
    this.parent = parent;
    
    setBorder(new EmptyBorder(4,4,4,4));
    
    VerticalFlowLayout layout = new VerticalFlowLayout();
    setLayout(layout);
    
    transcriptChooserPanel = new TranscriptChooserPanel(parent);
    domainSetChooserPanel = new DomainSetChooserPanel(parent);
    regionSetChooserPanel = new RegionSetChooserPanel(parent);
    
    JLabel highlightmodeLabel = new JLabel("Highlighting mode:");
    this.add(highlightmodeLabel);
    
    ButtonGroup highlightModeGroup = new ButtonGroup(); 
    highlightModeGroup.add(rdbtnHighlightModeAll);
    highlightModeGroup.add(rdbtnHighlightModeDomain);
    rdbtnHighlightModeAll.setToolTipText("Highlight all regions and variants");
    rdbtnHighlightModeDomain.setToolTipText("Highlight only those regions and variants that overlap with protein domains");
    rdbtnHighlightModeAll.setSelected(true);
    rdbtnHighlightModeAll.addActionListener(this);
    rdbtnHighlightModeDomain.addActionListener(this);
    this.add(rdbtnHighlightModeAll);
    this.add(rdbtnHighlightModeDomain);
    this.add(Box.createVerticalStrut(5));
    this.add(transcriptChooserPanel);
    this.add(Box.createVerticalStrut(5));
    this.add(domainSetChooserPanel);
    this.add(Box.createVerticalStrut(5));
    this.add(regionSetChooserPanel);
  }

  public void refreshTranscriptChooserPanel(){
    transcriptChooserPanel.refreshBoxes();
  }
  
  public void rebuildTranscriptChooserPanel(GPVGene selected){
    transcriptChooserPanel.rebuild(selected);
  }
  
  public void refreshDomainSetsPanel(final MainWindow parent){
    domainSetChooserPanel.rebuild();
  }
  
  
  public void refreshRegionSetsPanel(final MainWindow parent){
    regionSetChooserPanel.rebuild();
  }
  
  
  @Override
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource() == rdbtnHighlightModeAll){
      parent.getCanvas().getProperties().setRegionHighlightMode(CanvasProperties.REGION_HIGHLIGHT_MODE_ALL);
      parent.refreshCanvas();
    }else if(e.getSource() == rdbtnHighlightModeDomain){
      parent.getCanvas().getProperties().setRegionHighlightMode(CanvasProperties.REGION_HIGHLIGHT_MODE_DOMAIN);
      parent.refreshCanvas();
    }    
  }
}
