/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.sidebar;

import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map.Entry;

import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.GPVDomainSet;
import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.swing.MainWindow;
import at.icbi.gpviz.swing.VerticalFlowLayout;

public class DomainSetChooserPanel extends JPanel
{

  private static final long serialVersionUID = 5930572065355265085L;

  private MainWindow parent;
  
  private HashMap<String,JCheckBox> boxes;

  public DomainSetChooserPanel(final MainWindow main)
  {
    super();
    VerticalFlowLayout layout = new VerticalFlowLayout();
    setLayout(layout);
    this.parent = main;
    rebuild();
  }

  public void rebuild()
  {
    this.removeAll();
    boxes = new HashMap<String,JCheckBox>();

    GPVDataContainer data = GPViz.getInstance().getDataContainer();
    if (data != null)
    {
      ArrayList<GPVDomainSet> sets = data.getDomainSets();
      if (sets != null && sets.size() > 0)
      {

        JLabel title = new JLabel("Domain sets:");
        this.add(title);
        
        
        JPanel buttons = new JPanel();
        JButton hidenadditional = new JButton("Only used");
        String font = hidenadditional.getFont().getFamily();
        hidenadditional.setFont(new Font(font,Font.PLAIN,9));
        buttons.add(hidenadditional);
        buttons.setLayout(new FlowLayout(FlowLayout.LEFT));
        hidenadditional.addActionListener(new ActionListener(){
          @Override
          public void actionPerformed(ActionEvent e) {
            chooseOnlyAvailable();
          }
        });
        
        JButton showallbutton = new JButton("All");
        showallbutton.setFont(new Font(font,Font.PLAIN,9));
        buttons.add(showallbutton);
        
        this.add(buttons);
        
        showallbutton.addActionListener(new ActionListener(){
          @Override
          public void actionPerformed(ActionEvent e) {
            for(JCheckBox box : boxes.values()){
              box.setSelected(true);
            }
            parent.refreshCanvas();
          }
        });

        for (final GPVDomainSet set:sets)
        {
          set.setEnabled(true);
          JCheckBox box = new JCheckBox();
          box.addItemListener(new ItemListener()
          {
            
            @Override
            public void itemStateChanged(ItemEvent e)
            {
              set.setEnabled(((JCheckBox) e.getSource()).isSelected());
              parent.refreshCanvas();              
            }
          });
          
          box.setText(set.getSetName());
          box.setSelected(true);
          this.add(box);
          boxes.put(set.getSetName(), box);
        }
      }
    }

    this.revalidate();
  }

  
  private void chooseOnlyAvailable(){
    GPVGene gene = parent.getCanvas().getSelectedGene();
    GPVDataContainer data = GPViz.getInstance().getDataContainer();
    
    HashSet<String> availabledomains = data.getDomainSetsInGene(gene,true);
    
    for(Entry<String,JCheckBox> entry:boxes.entrySet()){
        entry.getValue().setSelected(availabledomains.contains(entry.getKey()));
    }
  }
  
  
}
