/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.sidebar;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;

import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import at.icbi.gpviz.GPViz;
import at.icbi.gpviz.data.GPVDataContainer;
import at.icbi.gpviz.data.regions.GPVHighlightedRegionSet;
import at.icbi.gpviz.swing.MainWindow;
import at.icbi.gpviz.swing.VerticalFlowLayout;

public class RegionSetChooserPanel extends JPanel implements MouseListener
{

  private static final long serialVersionUID = 5930572065355265085L;

  private MainWindow parent;
  
  private ImageIcon icon_delete_button;
  private ImageIcon icon_delete_button_mouseover;

  public RegionSetChooserPanel(final MainWindow main)
  {
    super();
    VerticalFlowLayout layout = new VerticalFlowLayout();
    setLayout(layout);
    this.parent = main;
    this.icon_delete_button = new ImageIcon(RegionSetChooserPanel.class.getResource("/at/icbi/gpviz/icons/kamiyamane/cross-small-grey.png"));
    this.icon_delete_button_mouseover = new ImageIcon(RegionSetChooserPanel.class.getResource("/at/icbi/gpviz/icons/kamiyamane/cross-small-grey_shiny.png"));
    rebuild();
  }

  public void rebuild()
  {
    this.removeAll();

    final GPVDataContainer data = GPViz.getInstance().getDataContainer();
    if (data != null)
    {
      ArrayList<GPVHighlightedRegionSet> sets = data.getHighlightedRegionSets();
      if (sets != null && sets.size() > 0)
      {

        JLabel title = new JLabel("Samples:");
        this.add(title);

        for (final GPVHighlightedRegionSet set:sets)
        {
          JCheckBox box = new JCheckBox(new Action()
          {
            @Override
            public void actionPerformed(ActionEvent e)
            {
              set.setEnabled(((JCheckBox) e.getSource()).isSelected());
              parent.refreshCanvas();
            }

            @Override
            public void setEnabled(boolean b)
            {
            }

            @Override
            public void removePropertyChangeListener(PropertyChangeListener listener)
            {
            }

            @Override
            public void putValue(String key, Object value)
            {
            }

            @Override
            public boolean isEnabled()
            {
              return true;
            }

            @Override
            public Object getValue(String key)
            {
              return null;
            }

            @Override
            public void addPropertyChangeListener(PropertyChangeListener listener)
            {
            }
          });
          
          box.setText(set.getSetName());
          box.setSelected(set.isEnabled());
          
          JButton delete = new JButton(icon_delete_button);
          delete.addMouseListener(this);
          delete.setOpaque(false);
          delete.setContentAreaFilled(false);
          delete.setBorderPainted(false);
          delete.setPreferredSize(new Dimension(16,16));
          delete.addActionListener(new ActionListener()
          {
            @Override
            public void actionPerformed(ActionEvent e)
            {
              data.removeHighlightedRegionsSet(set.getSetName());
            }
          });
          JPanel panel = new JPanel();
          panel.setLayout(new FlowLayout(FlowLayout.LEFT,0,0));
          panel.add(box);
          panel.add(delete);
          this.add(panel);
        }
      }
    }

    this.revalidate();
  }

  @Override
  public void mouseClicked(MouseEvent e)
  {
    
  }

  @Override
  public void mousePressed(MouseEvent e)
  {
    
  }

  @Override
  public void mouseReleased(MouseEvent e)
  {
    
  }

  @Override
  public void mouseEntered(MouseEvent e)
  {
    if(e.getSource() instanceof JButton){
      JButton b = (JButton) e.getSource();
      b.setIcon(icon_delete_button_mouseover);
    }
  }

  @Override
  public void mouseExited(MouseEvent e)
  {
    if(e.getSource() instanceof JButton){
      JButton b = (JButton) e.getSource();
      b.setIcon(icon_delete_button);
    }
  }

}
