/**
 *   GPViz: software for dynamic gene-centered visualization of genomic regions and/or variants
 *    Copyright (C) 2013  Rene Snajder
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package at.icbi.gpviz.swing.sidebar;

import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeListener;
import java.util.HashMap;
import java.util.TreeSet;

import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import at.icbi.gpviz.data.GPVGene;
import at.icbi.gpviz.data.GPVTranscript;
import at.icbi.gpviz.swing.MainWindow;
import at.icbi.gpviz.swing.VerticalFlowLayout;

public class TranscriptChooserPanel extends JPanel
{
  private GPVGene selectedGene;
  private MainWindow parent;
  
  private HashMap<String,JCheckBox> boxes;

  private static final long serialVersionUID = 5930572065355265085L;

  public TranscriptChooserPanel(final MainWindow main){
    super();
    VerticalFlowLayout layout = new VerticalFlowLayout();
    setLayout(layout);
    this.parent = main;
  }
  
  public void rebuild(GPVGene gene){
    this.removeAll();
    
    
    boxes = new HashMap<String,JCheckBox>();
    
    this.selectedGene = gene;
    if(selectedGene!=null){
      
      final TreeSet<GPVTranscript> transcripts =selectedGene.getSortedTranscripts();
      
      JLabel title = new JLabel("Transcripts:");
      this.add(title);
      JPanel buttons = new JPanel();
      
      JButton hidenoncodingbutton = new JButton("Only Coding");
      String font = hidenoncodingbutton.getFont().getFamily();
      hidenoncodingbutton.setFont(new Font(font,Font.PLAIN,9));
      buttons.add(hidenoncodingbutton);
      buttons.setLayout(new FlowLayout(FlowLayout.LEFT));
      hidenoncodingbutton.addActionListener(new ActionListener(){
        @Override
        public void actionPerformed(ActionEvent e) {
          for(final GPVTranscript transcript:transcripts){
            if(!transcript.isCoding()){transcript.setDisplayed(false);}
          }
          refreshBoxes();
          parent.refreshCanvas();
        }
      });
      
      JButton showallbutton = new JButton("All");
      showallbutton.setFont(new Font(font,Font.PLAIN,9));
      buttons.add(showallbutton);
      
      this.add(buttons);
      
      showallbutton.addActionListener(new ActionListener(){
        @Override
        public void actionPerformed(ActionEvent e) {
          for(final GPVTranscript transcript:transcripts){
            transcript.setDisplayed(true);
          }
          refreshBoxes();
          parent.refreshCanvas();
        }
      });
      
      for(final GPVTranscript transcript:transcripts){
        transcript.setDisplayed(true);
        JCheckBox box = new JCheckBox(new Action()
        {
          @Override
          public void actionPerformed(ActionEvent e){
            transcript.setDisplayed(((JCheckBox)e.getSource()).isSelected());
            parent.refreshCanvas();
          }
          @Override
          public void setEnabled(boolean b){}
          @Override
          public void removePropertyChangeListener(PropertyChangeListener listener){}
          @Override
          public void putValue(String key, Object value){}
          @Override
          public boolean isEnabled() {
            return true;
          }
          @Override
          public Object getValue(String key){return null;}
          @Override
          public void addPropertyChangeListener(PropertyChangeListener listener){}
        });

        box.setText(transcript.getTranscriptId());
        box.setSelected(true);
        this.add(box);
        boxes.put(transcript.getTranscriptId(),box);

      }
    }
    this.revalidate();
  }
  
  public void refreshBoxes(){
    if(selectedGene!=null && selectedGene.getTranscripts()!=null){
      for(GPVTranscript transcript:selectedGene.getTranscripts().values()){
        JCheckBox box = boxes.get(transcript.getTranscriptId());
        if(box!=null){
          box.setSelected(transcript.isDisplayed());
        }
      }
    }
  }

}
